
***********************************************************************************************************************
**
**   Name of Survey :   Iraq Household Socio-Economic Survey (IHSES) 2006-2007 
**   Subject :                IHSES Rationing Calculation and Tabulation 
**   Prepared by:         Sundus Al-hussieni
**   Date:	           Apr - 2008
**
*************************************************************************************************************************
*************************************************************************************************************************
**    Table 7-1:  Number of ration cards and persons registered by HH characteristics
**
**	Variables needed:
**
**                      (1) XGov
**		(2) Expenditure Categories 
**		(3) Household size Categories
**		(4) XSTRAT	
**		(5) No. of ration cards (Q0202)
**		(6) Registered in cards (Q0203_A,B,C)
**		
************************************************************************************************************************
** STEP 1:   We open the file with Expenditure and merge it with file IHSES01-Household
************************************************************************************************************************

GET
  FILE='C:\IHSES_TABLES\Originals\All expenditure by subgroup.sav'.

SORT CASES BY
  XHHKEY (A) . 

SAVE OUTFILE='C:\IHSES_TABLES\T7\All expenditure by subgroup.sav'  /COMPRESSED.

***************************************************************************************************************************
** STEP 2:  Get file IHSES01 and merge it with file Expenditure and save file with another name
***************************************************************************************************************************

GET
  FILE='C:\IHSES_TABLES\Originals\IHSES01-Household.sav'.

SORT CASES BY
  XHHKEY (A) .

MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\Originals\All expenditure by subgroup.sav'
 /BY xhhkey.
EXECUTE.

SAVE OUTFILE='C:\IHSES_TABLES\T7\temp-HH-Rations.sav'.

************************************************************************************************************
** STEP3:  Recode the variable " xstrat " & Q0202 " No.of ration cards HH"
**
************************************************************************************************************

**Enviroment

RECODE
  XSTRAT
  (2=2)  (1=3)  (3 thru 5=1)  INTO strat3.
VALUE LABELS  strat3  1'Gov.Centers' 2 'Other Uraban' 3'Rural' .
EXECUTE .

**No.of ration cards

DO IF (q0201 = 2) .
RECODE
  q0202  (0=SYSMIS)  .
END IF .
EXECUTE .

RECODE
  Q0202
  (0=0)  (1=1)  (2=2)  (3 thru Highest=3)  INTO  new202 .
VARIABLE LABELS new202 'No. of ration cards HH'.
EXECUTE .

VALUE LABELS new202 0'None' 1'1' 2'2' 3'3 and more' .
EXECUTE .

RECODE
  xhhsize
  (3=2)  (4=3)  (5=4)  (6=5)  (7=6)  (8=7)  (9=8)  (10=9)  (1 thru 2=1)  (11 thru 12=10) (13 thru Highest=11)   INTO  SIZEGR .
EXECUTE .

VALUE LABELS SIZEGR
 1'1-2'
 2'3' 
 3'4'
 4'5' 
 5'6' 
 6'7' 
 7'8' 
 8'9'
 9'10' 
 10'11-12' 
 11'13 & more'.
EXECUTE .

***************************************************************************************************
** STEP4:  Divided the variables "Q0203_A,B,C" (Registered in cards) by
**               the variable "Q0017" ( No. of households)
**
***************************************************************************************************

IF (xhhkey=285) q0203_b = SYSMIS(q0203_b) .
IF (xhhkey=565) q0203_b = SYSMIS(q0203_b) .
IF (xhhkey=14255) q0203_b = SYSMIS(q0203_b) .
EXECUTE .
IF (xhhkey=285) q0203_a = 5 .
IF (xhhkey=565) q0203_a = 5 .
IF (xhhkey=14255) q0203_a = 3 .
EXECUTE .

**Registered in cards

COMPUTE Age1 = Q0203_A / Q0017 .
VARIABLE LABELS Age1 'Registered in cards / Adults' .
EXECUTE .

COMPUTE Agelt1 = Q0203_B / Q0017 .
VARIABLE LABELS Agelt1 'Registered in cards / Age less than 1' .
EXECUTE .

COMPUTE Total = Q0203_C / Q0017 .
VARIABLE LABELS Total 'Registered in cards / Total ' .
EXECUTE .

*******************************************************************************************************		
**  STEP 5 : We Create new variables "Regien"
**
*******************************************************************************************************

RECODE
  xgov
  (11=1)  (13=1)  (15=1)  (23=2)  (ELSE=3)  INTO  Region .
EXECUTE .

VALUE LABELS Region
  1'Kurdistan'
  2 'Baghdad'
  3'Other Governorates'.
 EXECUTE . 


******************************************************************************************
** To transfer variable from scale to Nominal

VARIABLE LEVELS XGOV strat3 SIZEGR new202 Region (Nominal).
******************************************************************************************

WEIGHT
  BY weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=new202  Age1 Agelt1 Total xgov Region strat3 PCExpGr SIZEGR
    DISPLAY=DEFAULT
  /TABLE xgov + Region [C] + strat3 [C] + PCExpGr [C] + SIZEGR BY new202 [ROWPCT.COUNT F40.1] +  Age1 [MEAN
  F40.1] + Agelt1 [MEAN F40.1] + Total [MEAN F40.1]
  /CATEGORIES VARIABLES=new202 Region strat3 PCExpGr SIZEGR ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
   /CATEGORIES VARIABLES=xgov ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
   TITLE= 'Table 7-1 : Number of ration cards and persons registered by HH characteristics'.

WEIGHT
  OFF.

*****************************************************************************************************
**    Table 7-2:  Percentage of households receiving rations to total population 
**                      by houshold characteristics
**
**	Variables needed:
**                      (1) XGov
**		(2) Expenditure Categories 
**		(3) Household size Categories
**		(4) XSTRAT	
**		(5) HH receiving rations (Q0201)
**		(6) Persons receiving rations (Q0203_A,B,C)
**		
****************************************************************************************************
** STEP 1:   Compute Wieght persons
**
****************************************************************************************************

COMPUTE WeightPer = weight * xhhsize .
EXECUTE .

***************************************************************************************************
**     STEP2: Recode Variable Q0201 to classified HH & persons recieved Ration 
**                       (a) 1 that means HH & pearson recieved ration and ,
**                       (b) 0 that means HH & pearson dos not recieved ration
***************************************************************************************************

IF (Q0201 = 1) new_201 = 1 .
IF (Q0201 = 2) new_201 = 0 .
VARIABLE LABELS new_201 'HH receiving ration'.
EXECUTE .

**Persons receiving rations

COMPUTE new_203AB = SUM(Q0203_A,Q0203_B) .
EXECUTE .

IF (new_203AB <= XHHSIZE) new_203ab1 = new_203AB .
IF (new_203AB >=  XHHSIZE) new_203ab1 = XHHSIZE.
EXECUTE .

COMPUTE new_203ab2 = (new_203ab1 / XHHSIZE)*100 .
VARIABLE LABELS new_203ab2 'Person receving ration'.
EXECUTE .



WEIGHT
  BY weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=strat3 new_201 xgov Region PCExpGr SIZEGR DISPLAY=DEFAULT
  /TABLE xgov [ROWPCT.COUNT F40.1] + Region [ROWPCT.COUNT F40.1] + PCExpGr [C][ROWPCT.COUNT F40.1] + SIZEGR [ROWPCT.COUNT
  F40.1] BY strat3 > new_201 [C]
  /CATEGORIES VARIABLES=strat3 xgov Region PCExpGr SIZEGR ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=new_201 ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /TITLES
   TITLE= 'Table 7-2 a : Percentage of households receiving rations to total population by houshold characteristics'.

WEIGHT
  OFF.

WEIGHT
  BY WeightPer .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=new_203ab2 strat3 xgov Region PCExpGr SIZEGR DISPLAY=DEFAULT
  /TABLE xgov + Region + PCExpGr [C] + SIZEGR BY new_203ab2 [MEAN F40.1] > strat3
  /CATEGORIES VARIABLES=strat3 xgov Region PCExpGr SIZEGR ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
   TITLE= 'Table 7-2b : Percentage of Persons  receiving rations to total population by houshold characteristics'.

WEIGHT
  OFF.

SAVE OUTFILE='C:\IHSES_TABLES\T7\temp-HH-Rations.sav'  /COMPRESSED.
 
*************************************************************************************************************************
**    Table 7-3:  Percentage of househoulds and persons receiving rations to total population 
**                      by head of household characteristics
**	Variables needed:
**
**		(1) Employment status (Working, Unemployed, Housekeeper, With means, Other)
**		(2) Work sector (Private, Public, Other sectors, Not economically active)
**		(3) Economic Activity (Agriculture and fishing, Mining, Manufacturing, etc.)	
**		(4) Occupation (Legislators& senior officials & managers, Professionals, etc.)
**		(5) Working Status (Employee, Employer, Own Account, Not economically active)
**		(6) Age
**                  
*************************************************************************************************************************
** STEP 1:  We open the file with jobs, rename the Individual ID and save it with another name 
**
*************************************************************************************************************************

GET FILE='C:\IHSES_TABLES\Originals\IHSES10-Jobs.sav'.
rename variable Q1200_PE = XPERS.
SORT CASES BY XHHKEY (A)  XPERS (A) .
SAVE OUTFILE='C:\IHSES_TABLES\T7\Job_7-4.sav'  /COMPRESSED.

*****************************************************************************************************************
** STEP 2:  We select the "Main Occupation", following the criteria below:
**				
**		score = sum(months worked) /12 + sum(hours_worked)/40
**		Select job with Max score
**		
*****************************************************************************************************************

IF (Q1203_01<0) Q1203_01 = 0 . 
IF (Q1203_02<0) Q1203_02 = 0 . 
IF (Q1203_03<0) Q1203_03 = 0 . 
IF (Q1203_04<0) Q1203_04 = 0 . 
IF (Q1203_05<0) Q1203_05 = 0 . 
IF (Q1203_06<0) Q1203_06 = 0 . 
IF (Q1203_07<0) Q1203_07 = 0 . 
IF (Q1203_08<0) Q1203_08 = 0 . 
IF (Q1203_09<0) Q1203_09 = 0 . 
IF (Q1203_10<0) Q1203_10 = 0 . 
IF (Q1203_11<0) Q1203_11 = 0 . 
IF (Q1203_12<0) Q1203_12 = 0 . 
IF (Q1204_01<0) Q1204_01 = 0 . 
IF (Q1204_02<0) Q1204_02 = 0 . 
IF (Q1204_03<0) Q1204_03 = 0 . 
IF (Q1204_04<0) Q1204_04 = 0 . 
IF (Q1204_05<0) Q1204_05 = 0 . 
IF (Q1204_06<0) Q1204_06 = 0 . 
IF (Q1204_07<0) Q1204_07 = 0 . 
EXECUTE .

compute sum_mths 	= sum(Q1203_01, Q1203_02, Q1203_03, Q1203_04, Q1203_05, Q1203_06, Q1203_07, Q1203_08, Q1203_09, Q1203_10, Q1203_11, Q1203_12).
formats sum_mths (F3).
compute sum_hrs 	= sum(Q1204_01, Q1204_02, Q1204_03, Q1204_04, Q1204_05, Q1204_06, Q1204_07).
formats sum_hrs (F3).
compute score 	= sum( sum_mths/12,  sum_hrs/40, (4-Q1200_SN) / 4 ) .
formats score (F2.1).
EXECUTE .


*DELETE variable weight .
SAVE OUTFILE='C:\IHSES_TABLES\T7\Job_7-4.sav'  /COMPRESSED.
GET FILE='C:\IHSES_TABLES\T7\Job_7-4.sav'.

*************************************************************************************************************************************
***	We aggregate the number of hours for ALL possible activities of the individual:
*************************************************************************************************************************************

AGGREGATE
  /OUTFILE='C:\IHSES_TABLES\T7\temp_hrs12.sav'
  /BREAK=XHHKEY XPERS
  /sum_hrs12 = SUM(sum_hrs).

GET FILE='C:\IHSES_TABLES\T7\temp_hrs12.sav'.
SORT CASES BY   XHHKEY (A) XPERS.
SAVE OUTFILE='C:\IHSES_TABLES\T7\temp_hrs12.sav'.

GET FILE='C:\IHSES_TABLES\T7\Job_7-4.sav'.

AGGREGATE
  /OUTFILE='C:\IHSES_TABLES\T7\aggr.sav'
  /BREAK=XHHKEY XPERS
  /score = MAX(score).

GET FILE='C:\IHSES_TABLES\T7\Aggr.sav'.
SORT CASES BY   XHHKEY (A) XPERS (A) score (A) .
compute flag=1.
formats flag (N1).
SAVE OUTFILE='C:\IHSES_TABLES\T7\aggr.sav'  /COMPRESSED.

GET FILE='C:\IHSES_TABLES\T7\Job_7-4.sav' .
SORT CASES BY   XHHKEY (A) XPERS (A) score (A) .
SAVE OUTFILE='C:\IHSES_TABLES\T7\Job_7-4.sav'  /COMPRESSED.

MATCH FILES /FILE=*
 /TABLE='C:\IHSES_TABLES\T7\aggr.sav'  /BY XHHKEY XPERS score.
EXECUTE.

** We keep only the jobs that have max score, which means flag=1

FILTER OFF.
USE ALL.
SELECT IF(flag=1).
EXECUTE .


delete variables  flag, sum_mths, sum_hrs, score.

******************************************************************************************************************************************
** Now in the file Job_7-4.sav we have the MAIN job:
******************************************************************************************************************************************

SAVE OUTFILE='C:\IHSES_TABLES\T7\Job_7-4.sav'  /COMPRESSED.

******************************************************************************************************************************************
** STEP 3:  We open the file with individuals, and match the jobs from the new job's file and match the main
**	      occupation of each individual
*******************************************************************************************************************************************

GET  FILE='C:\IHSES_TABLES\Originals\IHSES02-Individuals.sav'.

SORT CASES BY   XHHKEY (A) XPERS.

MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T7\temp_hrs12.sav'
 /BY XHHKEY XPERS.
EXECUTE.


********************************************************************************************************************************************
** Drop variables that we don't need and save it with another name
********************************************************************************************************************************************

DELETE variables Q0501 Q0502_1 Q0502_2 Q0502_3 Q0502A_1 Q0502A_2 Q0502A_3 Q0503_A
  Q0504 Q0504A_1 Q0504A_2 Q0504A_3 Q0505_B Q0506 Q0507 Q0508_A Q0508_B Q0509 Q0510 Q0511 Q0512 Q0513 Q0514 Q0515 Q0516_1
  Q0516_2 Q0516_3 Q0516_4 Q0516_5 Q0516_6 Q0517 Q0518 Q0519 Q0520 Q0521_M Q0521_Y Q0522 Q0523 Q0524 Q0525 Q0526 Q0527 Q0528
  Q0529 Q0530 Q0531 Q0532 Q0533 Q0534 Q0601A Q0601B Q0601C Q0601D Q0601E Q0601F Q0602 Q0603_1 Q0603_2 Q0603_3 Q0603_4 Q0604_1
  Q0604_2 Q0604_3 Q0605_1 Q0605_2 Q0605_3 Q0606 .

SORT CASES BY  XHHKEY (A) XPERS (A) .


MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T7\Job_7-4.sav'
 /RENAME (XCLUSTer XGOV  XHHSIZE XSTRAT XWAVE = d0 d1  d3 d4 d5)
 /BY XHHKEY XPERS
 /DROP= d0 d1  d3 d4 d5.
EXECUTE.

*FILTER OFF.
USE ALL.
*SELECT IF(not missing(XCLUST)).
EXECUTE .


SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.

******************************************************************************************************************
** Now in the file Individuals_jobs.sav  we have all individuals and the MAIN 
** job if there is one, if not the variables related to main job are missing
******************************************************************************************************************

******************************************************************************************************************
** STEP 4:  Create variable Employ_status:
**		(1) Employment status
**			1. Working	
**			2. Unemployed	
**			3. Housekeeper		
**			4. With means	
**			5. Other	
**			6. No information on jobs
*****************************************************************************************************************
** We  create auxiliary variables:
**                        Working = 1 or 0
**                        Unemployed = 1 or 0
**                        Econ_active = sum(Working, Unemployed)
**           	   NotEc_activ = ~Econ_active
**                        
*****************************************************************************************************************
**	(1)  The person is classified as "Working" if has worked during the past 7 days (Q0701) or
**	      Q1204 >0 or was in temporarily away from work due to illness or vacation 
*****************************************************************************************************************

IF ( Q0701 >0 | sum_hrs12 >0 | Q0702 = 9) Working = 1 .
EXECUTE .

**************************************************************************************************************************
**	(2)  The person is classified as "Unemployed" if 
**		a) has NOT worked during the past 7 days (Q0702), and
**	      	b) wants to work (Q0703), and
**		c) the reason for working zero hours during the past 7 days if not alternative 9, and
**		d) has searched for a job in the past (Q0705), and
**		e) is available to start working (Q0707)	
**************************************************************************************************************************

IF ( Q0701 = 0 & ( sum_hrs12 = 0 | missing(sum_hrs12) ) &  Q0703 = 1 & Q0702 ~= 9 & Q0705 ~= 4 & Q0707 = 1) Unemployed = 1 .
EXECUTE .

COMPUTE Econ_active = SUM(Unemployed ,Working) .   
VARIABLE LABEL Econ_active  'Unemployed+Working'.
EXECUTE .

RECODE
  Econ_active  (SYSMIS=0)  .
EXECUTE .

IF (Econ_active = 0) NotEc_activ= 1 .
IF (Econ_active = 1) NotEc_activ= 0 .
EXECUTE .

*****************************************************************************************************************
**	(3)  The person is classified as "Houskeeper" if is housekeeper in Q0702 and if the reason in 
**	      Q0704 is not that has other source of income or that cannot find a job.
*****************************************************************************************************************

IF (Q0701 = 0 & ( sum_hrs12 = 0 | missing(sum_hrs12) ) & ( Q0703 <> 1 or missing(Q0703) )  & Q0702 = 7  &  Q0704  =  4 ) Housekeeper  = 1 .
EXECUTE .

*****************************************************************************************************************
**	(4)  The person is classified as "With means" if Q0702 between codes 5-6 or 8, and Reason 
**	      in Q0704 = 10.
*****************************************************************************************************************

IF (Q0701 = 0 & ( sum_hrs12 = 0 | missing(sum_hrs12) ) &  ( Q0702 = 5 | Q0702 = 6 | Q0702 = 8)  & Q0704 = 10 & NotEc_activ = 1) Withmeans = 1 .
EXECUTE .

*****************************************************************************************************************

*delete variables Employ_status.
execute.

IF (Working=1) 		            Employ_status=1.
IF (Unemployed=1) 			Employ_status=2.
IF (Housekeeper=1) 			Employ_status=3.
IF (Withmeans=1) 			Employ_status=4.
IF (missing(Employ_status)) 	            Employ_status=5.

VARIABLE LABEL Employ_status  'Employment status'.
VALUE LABELS Employ_status  1'Working' 2 'Unemployed' 3'Housekeeper' 4'Withmeans' 5' Other' .
EXECUTE .

VARIABLE LEVEL Employ_Status   (NOMINAL).

FREQUENCIES   VARIABLES=Employ_status   /ORDER=  ANALYSIS .


*****************************************************************************************************************
** STEP 5:  Create variable Sector:
**		(2) Work sector
**			1. Private	
**			2. Public	
**			3. Other sectors	
**			4. Not economically active	
**
*****************************************************************************************************************

IF (Q1202A =1) 				Sector  = Q1303 .
IF (Q1202B1=1|Q1202B2=1)       	Sector  = 3.
IF MISSING(Sector)                              Sector  = 11. 
IF ( NotEc_activ = 1 ) 			Sector  = 12.
IF (Unemployed=1) 		      	Sector  = 13.
VARIABLE LABELS Sector  'Work sector' .
EXECUTE .

RECODE
  Sector   (3=1)  (2=2)  (1=3) (4 thru 10=4)  (11=5) (12=6) (13=7) .
VALUE LABELS Sector  1'Private' 2'public' 3'Govermental' 4'other sectors'  5'Unknown'  6'Not economically active' 7'Unemployed' .

VARIABLE LEVEL Sector  (NOMINAL).

SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.
FREQUENCIES   VARIABLES=Sector   /ORDER=  ANALYSIS .

*****************************************************************************************************************
** STEP 6:  Create variable Occupation:
**			1. Legislators & senior officials & managers	
**			2. Professionals	
**			3. Technicians & associate professionals	
**			4. Clerks	
**			5. Services and sales workers	
**			6. skilled agriculture & fishery workers	
**			7. Craft & related trade workers	
**			8. Plant& machine operators& assembl.	
**			9. Elementary occupations	
**			10. Unknown	
**			11. Not economically active	
****************************************************************************************************************

COMPUTE Occupation  = TRUNC(Q1201/1000) .
EXECUTE .

IF (Occupation  > 0) Occupa_gr= Occupation.
IF (Occupation  = 0) Occupa_gr= 9.
IF MISSING(Occupa_gr)  Occupa_gr= 10.
IF (NotEc_activ  =1) Occupa_gr= 11.
IF (Unemployed=1)  Occupa_gr = 12.
EXECUTE .

VARIABLE LABELS Occupation  'Occupation' .
VARIABLE LABELS Occupa_gr  'Occupation group' .
EXECUTE .

VALUE LABELS Occupa_gr 
  1'Lagislatores and senior officials & mangers'
  2 'Professionals'
  3'Technicians & associate profess'
  4'Clerks'
  5'Services and sales workers'
  6'Skilled agriculture & fishery workers'
  7'Craft & related trade workers'
  8'Plant machine operatores & assemblers'
  9'Elementary Occupation'
10'Not sepicified'
11'Not Economically active'
12'Unemplyed'.
EXECUTE . 

VARIABLE LEVEL Occupa_gr  (NOMINAL).

FREQUENCIES   VARIABLES=Occupa_gr  /ORDER=  ANALYSIS .
SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.

*****************************************************************************************************************
** STEP 7:  Create variable Econ. activity:
**			1  'Agriculture & Hunting' 
 **			2  'Fishing'
 **			3  'Mining' 
 **			4  'Manufacturing industry' 
 **			5  'Electricity, gas ,water'
 **			6  'Building and construction' 
 **			7  'Wholesale & Retail Trade, repair of motor vehicles '
**			 8  'Trade,Resturant &Hotels'
**			 9  'Transportation &Communications'
**			 10'Finance  intermediation'
**			 11'Real estate , renting and business activities'
**			 12'Public administration and defence ; compulsory'
**			 13'Education'
**			 14'Health and Social Work'
**			 15'Other community , social and personal services activities '
**			 16'Housing services'
**			 17'Extra-territorial Organizations and bodies'
**			 18' Unknown'
**			 19' Not Economically active'
**			 20'Unemplyed' .
*****************************************************************************************************************

GET
  FILE='C:\IHSES_TABLES\Originals\IHSES11-Self-employment activities.sav'.

STRING 	 Act_cod (A1).
COMPUTE Act_cod = Q1205cod.
EXECUTE .

SORT CASES BY XHHKEY (A) Act_cod (A) .

SAVE OUTFILE='C:\IHSES_TABLES\T7\Self-employment activities_code.sav'.

GET FILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.

STRING      Act_cod (A1).
COMPUTE Act_cod = Q1202E .
EXECUTE .

SORT CASES BY XHHKEY (A) Act_cod (A) .

MATCH FILES /FILE=*
 /TABLE='C:\IHSES_TABLES\T7\Self-employment activities_code.sav'
 /RENAME (XCLUST XGOV XHHNO XHHSIZE XSTRAT XWAVE = d0 d1 d2 d3 d4 d5)
 /BY XHHKEY Act_cod 
 /DROP= d0 d1 d2 d3 d4 d5.
EXECUTE.

SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.

IF (MISSING(Q1302) | MISSING(Q1205ACT)) Per_Act = SUM(Q1302,Q1205ACT) .
VARIABLE LABELS Per_Act 'Persons Activity' .
EXECUTE .

COMPUTE Act_Gr  = TRUNC(Per_Act/10) .

VARIABLE LABELS Act_Gr 'Main Economic Activity' .
EXECUTE .

IF  ((Act_Gr=01|Act_Gr=02) | Q1202B1=1) 		Act_Gr=1.
IF  (Act_Gr=05) 					Act_Gr=2.
IF  (Act_Gr >= 10 & Act_Gr <= 14) 			Act_Gr=3.
IF  (Act_Gr >= 15 & Act_Gr <= 37) 			Act_Gr=4.
IF  (Act_Gr = 40 | Act_Gr = 41) 				Act_Gr=5.
IF  (Act_Gr = 45)   					Act_Gr=6.
IF  (Act_Gr >= 50 & Act_Gr <= 52) 			Act_Gr=7.
IF  (Act_Gr = 55) 					Act_Gr=8.
IF  (Act_Gr >= 60 & Act_Gr <= 64) 			Act_Gr=9.
IF  (Act_Gr >= 65 & Act_Gr <= 67) 			Act_Gr=10.
IF  (Act_Gr >= 70 & Act_Gr <= 74) 			Act_Gr=11.
IF  (Act_Gr =75) 					Act_Gr=12.
IF  (Act_Gr =80) 					Act_Gr=13.
IF  (Act_Gr =85) 					Act_Gr=14.
IF  (Act_Gr >= 90 & Act_Gr <= 93) 			Act_Gr=15.
IF  (Act_Gr >= 95 & Act_Gr <= 97) 			Act_Gr=16.
IF  (Act_Gr =99) 					Act_Gr=17.
IF MISSING (Act_Gr) 	             	     		Act_Gr=18.
IF (NotEc_activ >0) 					Act_Gr=19.
IF (Unemployed=1) 					Act_Gr=20 .
EXECUTE .

VALUE LABELS Act_Gr 
 1  'Agriculture & Hunting' 
 2  'Fishing'
 3  'Mining' 
 4  'Manufacturing industry' 
 5  'Electricity, gas ,water'
 6  'Building and construction' 
 7  'Wholesale & Retail Trade, repair of motor vehicles '
 8  'Trade,Resturant &Hotels'
 9  'Transportation &Communications'
 10'Finance  intermediation'
 11'Real estate , renting and business activities'
 12'Public administration and defence ; compulsory'
 13'Education'
 14'Health and Social Work'
 15'Other community , social and personal services activities '
 16'Housing services'
 17'Extra-territorial Organizations and bodies'
 18'Unknown'
 19' Not Economically active'
 20'Unemplyed' .
EXECUTE .

VARIABLE LEVEL Act_Gr  (NOMINAL).

FREQUENCIES   VARIABLES=Act_Gr  /ORDER=  ANALYSIS .
SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.

*****************************************************************************************************************
** STEP 8:  Create variable Work status:  Work_status
**			1. Employee	
**			2. Employer	
**			3. Own Account	
**			4. Not economically active	
*****************************************************************************************************************
**	We need to create two variables to be able to determine whether the person is 
**	employer or not.  The criteria is:
**
**	If (a) the household in agriculture or (b) the enterprise pays wages to employees, 
**	that means is employer
**
**	(1) Employer in Self-employment/enterprise, Ind_employer_in_self
**			if line 1431 or 1432 are > 0 	==> EMPLOYER
**	(2) Employer in Self-employment/enterprise, Ind_employer_in_agric
**			if Q1407H  > 0 or  Q1414_14 > 0 or Q1416CC > 0 or Q1417A > 0
**								==> EMPLOYER	
*****************************************************************************************************************

**	(1) Employer in Self-employment/enterprise, Ind_employer_in_self

GET FILE='c:\IHSES_TABLES\Originals\IHSES11-Self-employment activities.sav'.

COMPUTE Ind_employer_in_self = 0 .
IF (SUM(Q1431,Q1432) > 0) Ind_employer_in_self = 1 .
EXECUTE .
value lables Ind_employer_in_self  0 'No' 1 'Yes'.
SORT CASES BY XHHKEY (A) Q1205COD (A) .
SAVE OUTFILE='C:\IHSES_TABLES\T7\temp_self_emplyer.sav'  /COMPRESSED.

**	(2) Employer in agriculture, Ind_employer_in_agric

GET FILE='c:\IHSES_TABLES\Originals\IHSES06-Crop production.sav'.

AGGREGATE
  /OUTFILE='C:\IHSES_TABLES\T7\agr_crop_wage.sav'
  /BREAK=XHHKEY
  /Q1407H = SUM(Q1407H).

GET FILE='C:\IHSES_TABLES\T7\agr_crop_wage.sav'.
SORT CASES BY XHHKEY (A) .

SAVE OUTFILE='C:\IHSES_TABLES\T7\agr_crop_wage.sav'  /COMPRESSED.
 
GET FILE='c:\IHSES_TABLES\Originals\IHSES01-Household.sav'.
SORT CASES BY XHHKEY (A) .

MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T7\agr_crop_wage.sav'
 /BY XHHKEY.
EXECUTE.

SAVE OUTFILE='C:\IHSES_TABLES\T7\temp_HH_employer.sav'
  /DROP=XCLUST XHHSIZE Q0002 Q0003 Q0007 Q0008 Q0012 Q0014 Q0017 Q0018 Q0029 Q0032 Q0034 Q0035D Q0035M Q0035Y Q0036D Q0036M
  Q0036Y Q0037D Q0037M Q0037Y Q0038D Q0038M Q0038Y Q0039D Q0039M Q0039Y Q0040 QTUSE1 QLANG1 
 Q0301 Q0302 Q0303 Q0304 Q0305 Q0306 Q0307 Q0308A Q0308B Q0309_01 Q0310_01 Q0309_02
  Q0310_02 Q0309_03 Q0310_03 Q0309_04 Q0310_04 Q0309_05 Q0310_05 Q0309_06 Q0310_06 Q0309_07 Q0310_07 Q0309_08 Q0310_08
  Q0309_09 Q0310_09 Q0309_10 Q0310_10 Q0309_11 Q0310_11 Q0311A Q0311B Q0311C Q0312 Q0313 Q0314 Q0315 Q0316 Q0317 Q0318A Q0318B
  Q0318C Q0318D Q0319 Q0320 Q0321 Q0322 Q0323_1 Q0323_2 Q0323_3 Q0324_1 Q0325_1 Q0324_2 Q0325_2 Q0324_3 Q0325_3 Q0326_11
  Q0326_12 Q0326_13 Q0326_14 Q0326_15 Q0326_16 Q0326_21 Q0326_22 Q0326_23 Q0326_24 Q0326_25 Q0326_26 Q0326_31 Q0326_32
  Q0326_33 Q0326_34 Q0326_35 Q0326_36 Q0326_41 Q0326_42 Q0326_43 Q0326_44 Q0326_45 Q0326_46 Q0327 Q0328 Q0329 Q0330 Q0331_01
  Q0331_02 Q0331_03 Q0331_04 Q0331_05 Q0331_06 Q0331_07 Q0331_08 Q0331_09 Q0331_10 Q0331_11 Q0331_12 Q0331_13 Q0332 Q0334
  XQ0333_1 XQ0333_2 XQ0333_3 XQ0333_4 XQ0333_5 XQ0333_6 Q0335_01 Q0335_02 Q0335_03 Q0335_04 Q0335_05 Q0335_06 Q0335_07
  Q0335_08 Q0335_09 Q0335_10 Q0335_11 Q0335_12 Q0335_13 Q0335_14 Q0335_15 Q0335_16 Q0336_1 Q0336_2 Q0336_3 Q0336_4 Q0336_5
  Q0337_01 Q0337_02 Q0337_03 Q0337_04 Q0337_05 Q0337_06 Q0337_07 Q0338_01 Q0338_02 Q0338_03 Q0338_04 Q0338_05 Q0338_06
  Q0338_07 Q0339_01 Q0339_02 Q0339_03 Q0339_04 Q0339_05 Q0339_06 Q0339_07 Q1401 Q1402 Q1403_1 Q1403_2 Q1403_3 Q1403_4 Q1404
  Q1409 Q1410_01 Q1410_02 Q1410_03 Q1410_04 Q1410_05 Q1410_06 Q1410_07 Q1410_08 Q1411 Q1412 Q1413 Q1413A Q1414_01 Q1414_02
  Q1414_03 Q1414_04 Q1414_05 Q1414_06 Q1414_07 Q1414_08 Q1414_09 Q1414_10 Q1414_11 Q1414_12 Q1414_13 Q1414_15 Q1414_16
  Q1414_17 Q1414_18 Q1414_19 Q1414_20 Q1414_21 Q1414_22 Q1414_23 Q1414_24 Q1414_25 Q1415 Q1416A Q1416AA Q1416B Q1416BB Q1416C
  Q1417B Q1417C Q1417_A Q1417_B Q1417_C Q1417_D Q1602_01 Q1602_02 Q1602_03 Q1602_04 Q1602_05 Q1602_06 Q1602_07 Q1602_08
  Q1602_09 Q1602_10 Q1602_11 Q1602_12 Q1602_13 Q1602_14 Q1602_15 Q1602_16 Q1602_17 Q1602_18 Q1602_19 Q1602_20 Q1602_21
  Q1602_22 Q1602_23 Q1602_24 Q1602_25 Q1602_26 Q1602_27 Q1602_28 Q1602_29 Q1602_30 Q1602_31 Q1602_32 Q1602_33 Q1602_34
  Q1602_35 Q1602_36 Q1701 Q1702_1 Q1702_2 Q1702_3 Q1703_1 Q1703_2 Q1703_3 Q1704 Q1705_1 Q1705_2 Q1705_3 Q1801_01 Q1801_02
  Q1801_03 Q1801_04 Q1801_05 Q1801_06 Q1801_07 Q1801_08 Q1801_09 Q1801_10 Q1801_11 Q1802_01 Q1802_02 Q1802_03 Q1802_04
  Q1802_05 Q1802_06 Q1802_07 Q1802_08 Q1802_09 Q1802_10 Q1802_11 Q1802_12 Q1802_13 Q1802_14 Q1802_15 Q1802_16 Q1802_17
  Q1802_18 Q1802_19 Q1802_20 Q1802_21 Q1802_22 Q1802_23 Q1802_24 weight /COMPRESSED.

SAVE OUTFILE='C:\IHSES_TABLES\T7\temp_HH_employer.sav'


GET FILE='C:\IHSES_TABLES\T7\temp_HH_employer.sav'.

COMPUTE Ind_employer_in_agric = 0 .
IF (SUM(Q1414_14,Q1416CC,Q1417A,Q1407H) > 0) Ind_employer_in_agric= 1 .
EXECUTE .

value lables Ind_employer_in_agric
0 'No'
1 'Yes'.

SAVE OUTFILE='C:\IHSES_TABLES\T7\temp_HH_employer.sav'.
 
*************************************************************************************************************************************
** STEP 9:   We add both indicators into the file with individuals and their main job:  Individuals_jobs.sav

**************************************************************************************************************************************

GET FILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.
SORT CASES BY XHHKEY (A) .

MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T7\temp_HH_employer.sav'
 /RENAME (Q1407H Q1414_14 Q1416CC Q1417A XGOV XHHNO XSTRAT XWAVE = d0 d1 d2 d3 d4 d5 d6 d7)
 /BY XHHKEY
 /DROP= d0 d1 d2 d3 d4 d5 d6 d7.
EXECUTE.

SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.

GET FILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.
SORT CASES BY XHHKEY (A) Q1205COD (A) .


MATCH FILES /FILE=*
 /TABLE='C:\IHSES_TABLES\T7\temp_self_emplyer.sav'
 /RENAME (q1205act q1206_m1 q1206_m2 q1206_m3 q1206_m4 q1206_m5 q1418 q1419 q1420 q1421 q1422 q1423 q1424 q1425 q1426 q1427
  q1428 q1429 q1430 q1431 q1432 q1433 q1434 q1436 q1437 q1438 q1439 q1440 q1441 q1443 q1444a q1444b q1444c q1444d q1444e
  q1444f q1444g q1444h q1444i q1445 q1446 q1447 q1448 q1449 q1450 q1451 q1452 weight xclust xgov xhhno xhhsize xstrat xwave =
  d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 d32
  d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 d50 d51 d52 d53)
 /BY xhhkey q1205cod
 /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31
  d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 d50 d51 d52 d53.
EXECUTE.

SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.

*************************************************************************************************************************************
** STEP 10:       We create now the variable Work_status:
**			1. Employee	
**			2. Employer	
**			3. Own Account
**			4. Unknown	
**			5. Not economically active	
**			6. Unemployment	
*************************************************************************************************************************************

IF (Q1202A =1) 						            Work_status=1. 
IF (Q1202B1 =1) or  (Q1202B2 =1)			            Work_status=3.
IF (Ind_employer_in_agric=1) or  (Ind_employer_in_self=1)	Work_status=2.
IF MISSING (Work_status)                                               	Work_status=4.
IF (NotEc_activ=1) 					            Work_status=5. 
IF (Unemployed=1) 					            Work_status=6. 

var lab Work_Status "Work status".
value lab Work_Status
1 Employee	
2 Employer	
3 'Own Account'
4  'Unknown'
5 'Not Economically active'
6 'Unemployment'.
EXECUTE.

VARIABLE LEVEL Work_status  (NOMINAL).

FREQUENCIES   VARIABLES=Work_Status  /ORDER=  ANALYSIS .
 SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.


VARIABLE LEVEL Work_status  (NOMINAL).

FREQUENCIES   VARIABLES=Work_Status  /ORDER=  ANALYSIS .
 SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.

***************************

FILTER OFF.
USE ALL.
SELECT IF(xpers = 1).
EXECUTE .

SORT CASES BY
  xhhkey (A) .

SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_Xper.sav' /COMPRESSED.

GET
  FILE='C:\IHSES_TABLES\Originals\ihses01-household.sav'.

SORT CASES BY 
  xhhkey (A) .

MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T7\Individuals_Xper.sav'
 /RENAME (old_q010 old_q011 old_q012 old_q141 weight xbeea xcluster xgov xhhsize xstrat xwave = d0 d1 d2 d3 d4 d5 d6 d7 d8 d9
  d10)
 /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10.
EXECUTE.


***********************************************************************************************************************************
** STEP 11:      Now we use the final file (Individuals_jobs) to calculate the Table 
***********************************************************************************************************************************
 **          Recode Variable XSTRAT 
 **                      1. Gov. centers
 **                      2. Other urban
 **                      3. Rural  
***********************************************************************************************************************************

RECODE
  XSTRAT
  (2=2)  (1=3)  (3 thru 5=1)  INTO  strat3 .
VARIABLE LABELS Strat3 'Gov. centers, Other urban, and Rural'.

VALUE LABELS Strat3 1'Gov. centers'  2'Other urban'  3' Rural'.
EXECUTE .

VARIABLE LEVEL Strat3  (NOMINAL).

*************************************************************************************************************************************
**      Recode Variable Q0201 to classified HH & persons recieved Ration 
**                     (a) 1 that means HH & pearson recieved ration and ,
**                     (b) 0 that means HH & pearson dos not recieved ration
*************************************************************************************************************************************

IF (Q0201 = 1) new_201 = 1 .
IF (Q0201 = 2) new_201 = 0 .
VARIABLE LABELS new_201 'HH receving ration' .
EXECUTE .

COMPUTE new_203AB = SUM(Q0203_A,Q0203_B) .
VARIABLE LABELS new_203AB 'Persons reciving ration' .
EXECUTE .

IF (new_203AB <= XHHSIZE) new_203ab1 = new_203AB .
EXECUTE .

IF (new_203AB >=  XHHSIZE) new_203ab1 = XHHSIZE.
EXECUTE .

COMPUTE new_203ab2 = (new_203ab1 / XHHSIZE)*100 .
VARIABLE LABELS new_203ab2 'Person receving ration'.
EXECUTE .

**********************************************************************************************
**           Recode Variable Q0103     
**           
**********************************************************************************************

COMPUTE Agehh = Q0103 .
VARIABLE LABELS Agehh 'Age of head of HH' .
EXECUTE .

RECODE
  Agehh (Lowest thru 20=1)  (20 thru 29=2)  (30 thru 39=3)  (40 thru 49=4)  (50 thru 59=5)  (60 thru Highest=6)  .
EXECUTE .
VALUE LABELS Agehh 1'Less than 20' 2 '20 - 29' 3'30 - 39' 4'40 - 49' 5'50 - 59' 6'60 and more' .
EXECUTE .

VARIABLE LEVEL Agehh  (NOMINAL).

FILTER OFF.
USE ALL.
SELECT IF(xpers = 1).
EXECUTE .

RECODE
  Act_Gr
  (3=2)  (4=3)  (5=4)  (6=5)  (7=6)  (8=7)  (9=8)  (12=10)  (13=11)  (14=12)  (18=14)  (19=15)  (20=16)  (1 thru 2=1)  (10
  thru 11=9)  (ELSE=13)  INTO  Act13 .
EXECUTE .
VALUE LABELS Act13
 1  'Agriculture , Hunting & Fishing' 
 2  'Mining' 
 3  'Manufacturing industry' 
 4  'Electricity, gas ,water'
 5  'Building and construction' 
 6  'Wholesale & Retail Trade, repair of motor vehicles '
 7  'Trade,Resturant &Hotels'
 8  'Transportation &Communications'
 9'Financeintermediation & Real estate , renting and business activities'
 10'Public administration and defence ; compulsory'
 11'Education'
 12'Health and Social Work'
 13'Other services activity '
 14'Unknown Econ. activeity '
 15' Not Economically active'
 16'Unemplyed' .
EXECUTE .

VARIABLE LEVEL Act13  (NOMINAL).


************************************************************************************************
**WeightP 

COMPUTE WeightP = weight * xhhsize .
EXECUTE .

************************************************************************************************

WEIGHT
  BY Weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=strat3 q0201 Agehh Employ_status Sector Act13 Occupa_gr Work_status
    DISPLAY=DEFAULT
  /TABLE Agehh [ROWPCT.COUNT F40.1] + Employ_status [ROWPCT.COUNT F40.1] + Sector [ROWPCT.COUNT F40.1] + Act13 [ROWPCT.COUNT
  F40.1] + Occupa_gr [ROWPCT.COUNT F40.1] + Work_status [ROWPCT.COUNT F40.1] BY strat3 > q0201
  /CATEGORIES VARIABLES=strat3 Agehh Employ_status Sector Act13 Occupa_gr Work_status ORDER=A KEY=VALUE EMPTY=INCLUDE
  TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=q0201 ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
   TITLE= 'Table 7-3 : Percentage of househoulds and persons receiving rations to total population by head of household'+
 ' characteristics ( %)'.

WEIGHT
  OFF.

WEIGHT
  BY weightP .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=new_203ab2 strat3  Agehh  Employ_status  Sector Act13  Occupa_gr Work_status 
    DISPLAY=DEFAULT
  /TABLE Agehh [C] + Employ_status [C] + Sector [C] + Act13  [C] + Occupa_gr  [C] + Work_status  [C] BY new_203ab2 [MEAN F3.1] > strat3 [C]
  /CATEGORIES VARIABLES=strat3  Agehh Employ_status Sector Act13  Occupa_gr Work_status  ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES
  POSITION=AFTER
  /TITLES
   TITLE= 'Table 7-3 b : Precentage of households and persons receiving rations of total population by head of household' ''+
 ' characteristics (%) {Persons}' ''.

WEIGHT
  OFF.

SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuals_Xper.sav' /COMPRESSED.

**************************************************************************************************************************
**    Table 7-4:     Persons Receving Rations by their characteristics (% of total)
**
**	Variables needed:
**
**		(1) Age Grop
**		(2) Education
**		(3) Economic Activity (Agriculture and fishing, Mining, Manufacturing, etc.)	
**		(4) Occupation (Legislators& senior officials & managers, Professionals, etc.)

*************************************************************************************************************************		
**  STEP 1 : We Recode Variable Q0103 

*************************************************************************************************************************

GET
  FILE='C:\IHSES_TABLES\Originals\ihses01-household.sav'.

SAVE OUTFILE='C:\IHSES_TABLES\T7\Individuls 7_4.sav'
  /DROP=weight xcluster xstrat xgov xbeea xwave xhhsize xhhno q0002 q0003 q0007 q0008 q0012 q0014 q0017 q0018 q0029 q0032
  q0034 q0035d q0035m q0035y q0036d q0036m q0036y q0037d q0037m q0037y q0038d q0038m q0038y q0039d q0039m q0039y q0040 qtuse1
  qlang1 q0202 q0203_a q0203_b q0203_c q0204_a q0204_b q0204_c q0204_d q0301 q0302 q0303 q0304 q0305 q0306 q0307 q0308a q0308b
  q0309_01 q0310_01 q0309_02 q0310_02 q0309_03 q0310_03 q0309_04 q0310_04 q0309_05 q0310_05 q0309_06 q0310_06 q0309_07
  q0310_07 q0309_08 q0310_08 q0309_09 q0310_09 q0309_10 q0310_10 q0309_11 q0310_11 q0311a q0311b q0311c q0312 q0313 q0314
  q0315 q0316 q0317 q0318a q0318b q0318c q0318d q0319 q0320 q0321 q0322 q0323_1 q0323_2 q0323_3 q0324_1 q0325_1 q0324_2
  q0325_2 q0324_3 q0325_3 q0326_11 q0326_12 q0326_13 q0326_14 q0326_15 q0326_16 q0326_21 q0326_22 q0326_23 q0326_24 q0326_25
  q0326_26 q0326_31 q0326_32 q0326_33 q0326_34 q0326_35 q0326_36 q0326_41 q0326_42 q0326_43 q0326_44 q0326_45 q0326_46 q0327
  q0328 q0329 q0330 q0331_01 q0331_02 q0331_03 q0331_04 q0331_05 q0331_06 q0331_07 q0331_08 q0331_09 q0331_10 q0331_11
  q0331_12 q0331_13 q0332 q0334 q0335_01 q0335_02 q0335_03 q0335_04 q0335_05 q0335_06 q0335_07 q0335_08 q0335_09 q0335_10
  q0335_11 q0335_12 q0335_13 q0335_14 q0335_15 q0335_16 q0336_1 q0336_2 q0336_3 q0336_4 q0336_5 old_q033 old_q034 old_q035
  old_q036 old_q037 old_q038 old_q039 old_z_da old_z_d1 old_z_d2 old_z_d3 old_z_d4 old_z_d5 old_z_d6 q0339_01 q0339_02
  q0339_03 q0339_04 q0339_05 q0339_06 q0339_07 q1401 q1402 q1403_1 q1403_2 q1403_3 q1403_4 q1404 q1409 q1410_01 q1410_02
  q1410_03 q1410_04 q1410_05 q1410_06 q1410_07 q1410_08 q1411 q1412 q1413 q1413a q1414_01 q1414_02 q1414_03 q1414_04 q1414_05
  q1414_06 q1414_07 q1414_08 q1414_09 q1414_10 q1414_11 q1414_12 q1414_13 q1414_14 q1414_15 q1414_16 q1414_17 q1414_18
  q1414_19 q1414_20 q1414_21 q1414_22 q1414_23 q1414_24 q1414_25 q1415 q1416a q1416aa q1416b q1416bb q1416c q1416cc q1417a
  q1417b q1417c q1417_a q1417_b q1417_c q1417_d q1602_01 q1602_02 q1602_03 q1602_04 q1602_05 q1602_06 q1602_07 q1602_08
  q1602_09 q1602_10 q1602_11 q1602_12 q1602_13 q1602_14 q1602_15 q1602_16 q1602_17 q1602_18 q1602_19 q1602_20 q1602_21
  q1602_22 q1602_23 q1602_24 q1602_25 q1602_26 q1602_27 q1602_28 q1602_29 q1602_30 q1602_31 q1602_32 q1602_33 q1602_34
  q1602_35 q1602_36 q1701 q1702_1 q1702_2 q1702_3 q1703_1 q1703_2 q1703_3 q1704 q1705_1 q1705_2 q1705_3 q1801_01 q1801_02
  q1801_03 q1801_04 q1801_05 q1801_06 q1801_07 q1801_08 q1801_09 q1801_10 q1801_11 q1802_01 q1802_02 q1802_03 q1802_04
  q1802_05 q1802_06 q1802_07 q1802_08 q1802_09 q1802_10 q1802_11 q1802_12 q1802_13 q1802_14 q1802_15 q1802_16 q1802_17
  q1802_18 q1802_19 q1802_20 q1802_21 q1802_22 q1802_23 q1802_24 old_q003 old_q141 q0333_x1 q0333_x2 q0333_x3 q0333_x4
  q0333_x5 q0333_x6 z_gap1 z_days1 q0338_1 q0337_1 z_gap2 z_days2 q0338_2 q0337_2 z_gap3 z_days3 q0338_3 q0337_3 old_q013
  z_gap4 z_days4 q0338_4 q0337_4 old_q014 z_gap5 z_days5 q0338_5 q0337_5 old_q015 z_gap6 z_days6 q0338_6 q0337_6 old_q016
  z_gap7 z_days7 q0338_7 q0337_7 old_q030 old_q031 old_q032 V377 V378 V379 V380 V381 V382 V383 V384 V385 V386 V387 V388 V389
  V390 V391 V392 old_q017 old_q020 oldQ1701 test1701 New1701 Nq0302 /COMPRESSED.

GET
  FILE='C:\IHSES_TABLES\T7\Individuls 7_4.sav'.

SORT CASES BY
  xhhkey (A) .

GET
  FILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.

DELETE variables q0201

SORT CASES BY
  xhhkey (A) .

MATCH FILES /FILE=*
 /TABLE='C:\IHSES_TABLES\T7\Individuls 7_4.sav'
 /BY xhhkey.
EXECUTE.
  
RECODE
      Q0103
      (0 thru 4 = 1)(5 thru 9 = 2)(10 thru 14 = 3)(15 thru 19 = 4)(20 thru 24 = 5)(25 thru 29 = 6)
      (30 thru 34 = 7)(35 thru 39 = 8)(40 thru 44 = 9)(45 thru 49 = 10)(50 thru 54 = 11) (55 thru 59 = 12) (60 thru 64 = 13) 
      (65 thru Highest = 14) INTO AgeGrps .
VARIABLE LABELS AgeGrps 'Age groups' .
VALUE LABELS AgeGrps
 1 '0- 4' 
 2 '5- 9' 
 3'10-14'
 4'15-19'
 5'20- 24' 
 6'25- 29' 
 7'30- 34'
 8'35- 39'
 9'40- 44' 
 10'45- 49'
 11'50- 54'
 12'55- 59'
 13'60- 64'
 14'65 and more'.
EXECUTE .

VARIABLE LEVEL AgeGrps  (NOMINAL).

******************************************************************************************************************************************
**   STEP 2 : Recode variable (Q0406)
**                 
******************************************************************************************************************************************


RECODE
  q0406
  (1=1)  (2=2)  (3=3)  (4=4)  (5=5)  (8=7) (9=8) (6 thru 7=6) (10 thru 12=9) (13=10)   INTO  new_406 .
EXECUTE .

VALUE LABELS new_406 
 1'illetrate' 
 2'Read only'
 3'Read and Write' 
 4'Primary' 
 5'Intermediate' 
 6'Secondary or equivalent' 
 7'Technical diploma' 
 8'Bachelors degree' 
 9'Higher than bachelors degree'
 10'Other'  
EXECUTE .

  FREQUENCIES VARIABLES=new_406  / ORDER= ANALYSIS.

******************************************************************************************************************************************
**   STEP 3 : Create variable "Education Status" if:
**                  a) Q0402=1 ,We calculate the education from the variable (new_406) , and if
**                  b) Q0402=2 ,We calculate the education from the variable (Q0410) , and if
**                  c) Q0402=3 ,We calculate the education from the variable (Q0404)

********************************************************************************************************************************************

IF  (Q0402=1 )EducGrp= new_406 .

IF  (Q0402=2 & Q0410L=1&Q0410C=1) EducGrp=1.
IF  (Q0402=2 & Q0410L=1&Q0410C=2 | Q0410C=3 ) EducGrp=2.
IF  (Q0402=2 & Q0410L=1&Q0410C=4 | Q0410C=5 | Q0410C=6) EducGrp=3.

IF  (Q0402=2 & Q0410L=2) EducGrp=4.
IF  (Q0402=2 & Q0410L=3) EducGrp=5.
IF  (Q0402=2 & Q0410L=4) EducGrp=6.
IF  (Q0402=2 & Q0410L=5) EducGrp=6.
IF  (Q0402=2 & Q0410L=6) EducGrp=8.
IF  (Q0402=2 & Q0410L=7) EducGrp=10.

IF (Q0402=3 & Q0404=1) EducGrp=1.
IF (Q0402=3 & Q0404=2) EducGrp=2.
IF (Q0402=3 & Q0404=3) EducGrp=3.
IF ( (  MISSING (Q0402  )  & q0103<15) ) EducGrp = 12 .
IF MISSING (EducGrp)  EducGrp=11

RECODE
  EducGrp
  (1=1)  (2=2)  (3=3)  (4=4)  (5=5)  (6=6)  (7=7) (8=8) (9 =9) (10=10) (11=11) (12=12)  INTO  EducGrp .
VARIABLE LABLES EducGrp 'Education status'.
VALUE LABELS EducGrp
 1'illetrate' 
 2'Read only'
 3'Read and Write' 
 4'Primary' 
 5'Intermediate' 
 6'Secondary or equivalent' 
 7'Technical diploma' 
 8'Bachelors degree' 
 9'Higher than bachelors degree'
 10'Other'  
 12'Less than 15 Yrs old'
 11'Unknown'.
EXECUTE .

DO IF (q0103 <= 15) .
RECODE
  EducGrp  (6 thru 8=11)  .
END IF .
EXECUTE .

VARIABLE LEVEL EducGrp (NOMINAL).
  FREQUENCIES VARIABLES=EducGrp  / ORDER= ANALYSIS.

******************************************************************************************************************************************
**   STEP 4: We recode variable "EducGrp" to merge " read / read & write" in one catogarie
**                 
******************************************************************************************************************************************

RECODE
  EducGrp
  (1=1)  (4=3)  (5=4) (6 =5) (7 =6) (8=7)  (9=8)  (10=9) (11 =10) (2 thru 3=2) (12 =11)   INTO  EducGrp9 .
VARIABLE LABELS EducGrp9.
EXECUTE .

VALUE LABELS EducGrp9
 1'illitrate' 
 2 'read or read & write' 
 3'Primary' 
 4'Intermediate' 
 5'Secondary or equivalent '
 6'Technical Diploma' 
 7'Bachelors degree' 
 8'Higher than bachelors degree'
 9'Other' 
11'Less than 15 Yrs old'
10'Unknown'.
EXECUTE .

VARIABLE LEVEL EducGrp9 (NOMINAL).

  FREQUENCIES VARIABLES=EducGrp9  / ORDER= ANALYSIS.

RECODE
  XSTRAT
  (2=2)  (1=3)  (3 thru 5=1)  INTO  strat3 .
VARIABLE LABELS Strat3 'Gov. centers, Other urban, and Rural'.

VALUE LABELS Strat3 1'Gov. centers'  2'Other urban'  3' Rural'.
EXECUTE .

VARIABLE LEVEL Strat3  (NOMINAL).

WEIGHT
  BY weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=strat3 q0201 AgeGrps EducGrp9 Act13 Occupa_gr DISPLAY=DEFAULT
  /TABLE AgeGrps [ROWPCT.COUNT F40.1] + EducGrp9 [ROWPCT.COUNT F40.1] + Act13 [ROWPCT.COUNT F40.1] + Occupa_gr [ROWPCT.COUNT
  F40.1] BY strat3 > q0201
  /CATEGORIES VARIABLES=strat3 AgeGrps EducGrp9 Act13 Occupa_gr ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=q0201 ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
   TITLE= 'Table 7-4:  Persons Receving Rations by their characteristics (% of total)'.

WEIGHT
  OFF.

*************************************************************************************************************************************
**    Table 7-5:  Cost of rations and their market value by houshold characteristics
**
**	Variables needed:
**
**		(1) Q0204_A,B,CD
**		(2) XGOV
**		(3) Strat3	
**		(4) Expenditur Capita Grp
**		(5) Household size Categories 
**
******************************************************************************************************************************************
** STEP 1 :     We Get file HH_Rations table and recode the variable (Q0204_A,B,C,D) from the value (-1,-2,-3)
**
******************************************************************************************************************************************

GET
  FILE='C:\IHSES_TABLES\T7\temp-HH-Rations.sav'.

**********************************************************************************************************************************************
** STEP 2 :   We multiply the variable value (Q0204_A,B,C,D) by (1000) to transfer the value from (000 ID) to ( ID ) 
**                  and divided by househoulds size
**********************************************************************************************************************************************

COMPUTE new_204A = Q0204_A * 1000 / XHHSIZE .
VARIABLE LABELS new_204A 'Value paid (ID/capita)' .
EXECUTE .

COMPUTE new_204B = Q0204_B * 1000 / XHHSIZE .
VARIABLE LABELS new_204B 'Delivery to residence (ID / capita)' .
EXECUTE .

COMPUTE new_204C = Q0204_C * 1000 / XHHSIZE .
VARIABLE LABELS new_204C 'Bags (ID / capita)' .
EXECUTE .

COMPUTE new_204D = Q0204_D * 1000 / XHHSIZE .
VARIABLE LABELS new_204D 'Total (ID/capita)' .
EXECUTE .


WEIGHT
  BY weight .


* Custom Tables.
CTABLES
  /VLABELS VARIABLES=new_204A new_204B new_204C new_204D XGOV Region strat3 PCExpGR  SIZEGR
    DISPLAY=DEFAULT
  /TABLE XGOV [C] + Region [C] + strat3 [C] + PCExpGR  [C] + SIZEGR [C] BY new_204A [MEAN F5] + new_204B [MEAN F5] + new_204C [MEAN F5] + new_204D [MEAN F5]
  /CATEGORIES VARIABLES=XGOV Region strat3 PCExpGR  SIZEGR ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
   TITLE= 'Table 7-5 : Cost of rations and their market value by houshold characteristics'.


SAVE OUTFILE='C:\IHSES_TABLES\T7\temp-HH-Rations.sav'.
 
WEIGHT
  OFF.


*************************************************************************************************************************************
**    Table 7-6 :  Distribution of househoulds by period of receiving last rations and Urban & Rural (%)
**
**	Variables needed:
**
**		(1) Q0205
**		(2) Strat2
**		(3) XRATION 	
**
***************************************************************************************************************************************
** STEP 1 :   We Get file ihses08-ration items
**
***************************************************************************************************************************************

GET
  FILE='C:\IHSES_TABLES\Originals\ihses08-ration items.sav'.

***************************************************************************************************************************************
** STEP 2 :     We recode variable (XRATION) in a different variable and in the same times we defined two
**                    additional items (Tomato past & White flour)
****************************************************************************************************************************************

RECODE
  XRATION
  (1=1)  (2=2)  (3=3)  (4=4)  (5=5)  (6=6)  (7=7)  (8=8)  (9=9)  (10=10)  (11=11)  (12=12)  (13=13)  (14=14)  (15=15)
  (16=16)  (17 thru Highest=SYSMIS)  INTO  XRation1 .
VARIABLE LABELS XRation1 'XRation Item (1-16)'.
EXECUTE .

VALUE LABELS XRation1
 1'Wheat flour'
 2 'Rice'
 3'Sugar'
 4'Vegetable oil'
 5'Chick peas'
 6'White beans'
 7'Lentil' 
 8'Tea'
 9'TMilk (powered)'
 10'Salt'
 11'Soap'
 12'Detergent'
 13'Infant formula, powered'
 14'Weaning Cereal'
 15'Tomato Past'
 16'White Flour'.
EXECUTE .

VARIABLE LEVELS XRation1 (Nominal).

***************************************************************************************************************************************
** STEP 3 :     We recode variable (xstrat) , and the variable (Q0205) from the value (-1,-2,-3) 
**                    
****************************************************************************************************************************************

RECODE
  XSTRAT
  (1=2)  (2 thru 5=1)  INTO  strat2.
EXECUTE .

VALUE LABELS strat2 1'Urban' 2'Rural' .
EXECUTE .

VARIABLE LEVELS strat2 (Nominal).

RECODE
  Q0205 
  (1=1)  (2=2)  (3=3)  (4=4)  (0=SYSMIS)  (Lowest thru -1=SYSMIS)  INTO  new_205 .
EXECUTE .
VALUE LABELS new_205 1'Past month' 2'3 Past months' 3'Longer than 3 months-12 months' 4'Never received'.
EXECUTE .

VARIABLE LEVELS new_205  (Nominal).



WEIGHT
  BY weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=new_205 strat2 XRation1 DISPLAY=DEFAULT
  /TABLE strat2 [C] > XRation1 [C][ROWPCT.COUNT F40.1] BY new_205 [C]
  /CATEGORIES VARIABLES=new_205 strat2 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=XRation1 ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
   TITLE= 'Table 7-6 : Distribution of househoulds by period of receiving last rations and Urban & Rural (%)'.

WEIGHT
  OFF.


*************************************************************************************************************************************
**    Table 7-7 :  Quantities received of rations and how they were utilized by item ( Urban & Rural )
**
**	Variables needed:
**
**		(1) Quantity received (KG/cap./mn.)
**		(2) Quantity given away (KG/cap./mn.)
**		(3) Quantity given away (% of received)
**                      (4) Quantity sold or barterd (KG/cap./mn.)
**                      (5) Quantity sold or bartered (% of received)
**                      (6) Value of quantity sold or bartered (ID/HH/month)
**                      (7) XRATION
**                      (8) Strat2

*************************************************************************************************************************************
** STEP 1 :   We create the variabls :
**                       (1) The variabls (Q0206,Q0209,Q0210,Q0212) divided by the vairable (Q0207) to obtain the
**                            quantity per month
**                       (2) Divided the variable (Q0209) by the variable (Q0206) to obtian quantity given away 
**                            from quantity received
**                       (3) Divided the variable (Q0210) by the variable (Q0206) to obtain quantity sold or bartered
**                            from quantity received 
**                       (4) The new create variable (Value of quantity sold or bartered ) multiply by (1000) to transfer
**                             the value from (000 ID) to ( ID ) 
*************************************************************************************************************************************


COMPUTE new_206 = Q0206 / Q0207 .
VARIABLE LABELS new_206 'Quantity received (KG/cap./mn.)' .
EXECUTE .

COMPUTE new_209 = Q0209 / Q0207 .
VARIABLE LABELS new_209 'Quantity given away (KG/cap./mn.)' .
EXECUTE .

COMPUTE Quantitygiven = Q0209 / Q0206 *100 .
VARIABLE LABELS Quantitygiven 'Quantity given away (% of received)' .
EXECUTE . 

COMPUTE new_210 = Q0210 / Q0207 .
VARIABLE LABELS new_210 'Quantity sold or bartered (KG/cap./mn.)' .
EXECUTE .

COMPUTE Quntitysold = Q0210 / Q0206 *100 .
VARIABLE LABELS Quntitysold 'Quantity sold or bartered (% of received)' .
EXECUTE .

COMPUTE new212 = Q0212 / Q0207 .
VARIABLE LABELS new212 'Value of quantity sold or bartered(ID/HH/month )' .
EXECUTE .

DO IF (new_210 >= 0) .
RECODE
  new212  (SYSMIS=0)  .
END IF .
EXECUTE .

COMPUTE new_212 = new212*1000 .
VARIABLE LABELS new212 'Value of quantity sold or bartered(ID/HH/month )' .
EXECUTE .



WEIGHT
  BY weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=new_206 new_209 Quantitygiven new_210 Quntitysold new_212 strat2 xration
    DISPLAY=DEFAULT
  /TABLE strat2 > xration BY new_206 [MEAN] + new_209 [MEAN] + Quantitygiven [MEAN F40.1] + new_210 [MEAN] + Quntitysold
  [MEAN F40.1] + new_212 [MEAN F40.0]
  /CATEGORIES VARIABLES=strat2 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=xration ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
   TITLE= 'Table 7-7 :  Quantities received of rations and how they were utilized by item ( Urban & Rural )'.

WEIGHT
  OFF.


**************************************************************************************************************
**    Table 7-8 :  To whom the rations were given, sold or bartered and reason by 
**                       item and urban & rural (%)
**	Variables needed:
**
**		(1) Q0211
**		(2) Q0213
**		(3) XRATION 	
**                      (4) Strat2
** 
***************************************************************************************************************
** STEP 1 :   We recode the variables (Q0211,Q0213)  from the value (0)
**
***************************************************************************************************************

RECODE
  q0211 q0213  (0=SYSMIS)  .
EXECUTE .

DO IF (xration = 10) .
RECODE
  q0213  (3=SYSMIS)  .
END IF .
EXECUTE .

*****************************************************************************************************************
** STEP 2 :    We merge the category (3+4)  in the variable (Q0211) 
**
*****************************************************************************************************************

RECODE
  Q0211  (1=1)  (2=2)  (5=4)  (3 thru 4=3)  .
EXECUTE .

VALUE LABELS Q0211 1'Relative/friend' 2 'Ration agent' 3'Buyers or barterers' 4'Others' .
EXECUTE .

VARIABLE LEVELS Q0211 Q0213  (Nominal).


WEIGHT
  BY weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=Q0213 Q0211 strat2 XRation1 DISPLAY=DEFAULT
  /TABLE strat2 [C] > XRation1 [C][ROWPCT.COUNT F40.1] BY Q0213 [C] + Q0211 [C]
  /CATEGORIES VARIABLES=Q0213 Q0211 strat2 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=XRation1 ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
   TITLE= 'Table 7-8 : To whom the rations were given, sold or bartered and reason by item and urban & rural (%)'.

WEIGHT
  OFF.

********************************************************************************************************************************************
**    Table 7-9 :  The source of quantities of rations consumed during last 30 days by item and Urban & Rural (%)
**
**	Variables needed:
**
**		(1) Source of quantities of ration (Q0215,Q0216,Q0217,Q0220,Q0221)
**		(2) XHHSIZE
**		(3) XRATION 	
**                      (4) Strat2
** 
*********************************************************************************************************************************************
** STEP 1 :    create new two variables :
**                               (1) source_consumed (this variable accumulating from the variables (Q0215,Q0216,Q0217,
**                                      Q0220,Q0221) ,and put it in on variable
**
**                               (2) total consumption (this variable is totalling from the variables above ,and the score is
**                                    divided by the variable (XHHSIZE)       
*********************************************************************************************************************************************

IF (Q0215 >= 1) sourse_consumed = 1 .
IF (Q0216 >= 1) sourse_consumed = 2 .
IF (Q0217 >= 1) sourse_consumed = 3 .
IF (Q0220 >= 1) sourse_consumed = 4 .
IF (Q0221 >= 1) sourse_consumed = 5 .
VARIABLE LABELS sourse_consumed 'source of quantities of ration consumed' .
EXECUTE .

VALUE LABELS sourse_consumed
 1'Reeceived as part of rations' 
 2 'Purchased from selling rations' 
 3'Purchased' 
 4'Received as gift' 
 5'Other sources' .
EXECUTE .

VARIABLE LEVELS sourse_consumed  (Nominal).

COMPUTE Total_cons = SUM(Q0215,Q0216,Q0217,Q0220,Q0221) .
VARIABLE LABELS Total_cons 'Total consumption' .
EXECUTE .

COMPUTE totalcon = Total_cons / XHHSIZE .
VARIABLE LABELS totalcon 'Total consumption (KG/capita)' .
EXECUTE .

WEIGHT
  BY weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=sourse_consumed totalcon strat2 XRation1 DISPLAY=DEFAULT
  /TABLE strat2 [C] > XRation1 [C] BY sourse_consumed [C][ROWPCT.COUNT F40.1] + totalcon [MEAN]
  /CATEGORIES VARIABLES=sourse_consumed strat2 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=XRation1 ORDER=A KEY=VALUE EMPTY=INCLUDE 
  /TITLES
   TITLE= 'Table 7-9 : The source of quantities of rations consumed during last 30 days by item and Urban & Rural (%)'.


WEIGHT
  OFF.

**********************************************************************************************************************************
**    Table 7-10 :  Distribution of houeholds by reason for purchasing rations item from market 
**                         and purchased quantity, value and price by item and urban & rural
**
**	Variables needed:
**
**		(1) Q0219
**		(2) Quantity Purchased (Q0216,Q0217)
**		(3) Q0218 	
**		(2) price
**		(3) XHHSIZE 	
**		(2) XRATION
**		(3) strat2 	

***********************************************************************************************************************************
** STEP 1 :   We merge the category (3+4)  in the variable (Q0219) and recoded it in new variable 
**
***********************************************************************************************************************************

RECODE
  Q0219
  (3=2)  (4=3)  (1 thru 2=1)  INTO  new_219 .
EXECUTE .
VARIABLE LABELS new_219 'Main reason for purchasing (%)' .
EXECUTE .
VALUE LABELS new_219  1'Ration & gift not enough' 2'To get better quality' 3' Other reasons' .
EXECUTE .

VARIABLE LEVELS new_219  (Nominal).

COMPUTE new_quintity = SUM(Q0216,Q0217) / XHHSIZE .
EXECUTE .
VARIABLE LABELS new_quintity 'Quantity Purchased (KG/capita)' .
EXECUTE .

COMPUTE new_218 = Q0218 *1000 / XHHSIZE .
VARIABLE LABELS new_218 'Value (ID/capita)' .
EXECUTE .

COMPUTE new_208 = Q0208 *1000.
VARIABLE LABELS new_208 'Price (ID/KG)' .
EXECUTE .

DO IF (new_quintity = 0 | new_218 = 0 | new_208 = 0) .
RECODE
  new_218 new_208 new_quintity  (ELSE=0)  .
END IF .
EXECUTE .

RECODE
  new_quintity new_218 new_208  (0=SYSMIS)  .
EXECUTE .

WEIGHT
  BY weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=new_219 new_quintity new_218 new_208 strat2 xration DISPLAY=DEFAULT
  /TABLE strat2 > xration BY new_219 [ROWPCT.COUNT F40.1] + new_quintity [MEAN] + new_218 [MEAN] + new_208 [MEAN]
  /CATEGORIES VARIABLES=new_219 strat2 ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=xration ORDER=A KEY=VALUE EMPTY=INCLUDE
  /TITLES
   TITLE= ' Table 7-10 :  Distribution of houeholds by reason for purchasing rations item from market and purchased quantity,'+
 ' value and price by item and urban & rural'.

WEIGHT
  OFF.

SAVE OUTFILE='C:\IHSES_TABLES\T7\temp-HH XRations table.sav'.
 

********************************************************************************************************************************************
**    Table 7-11 :  Value paid,market value, value of sold and bartered, and value of purchased of rations items 
**                         by expenditure groups
**
**	Variables needed:
**
**		(1) purchase of rations items last 30 days
**		(2) Q0212
**		(3) Q0208 	
**		(2) Q024_A
**		(3) XHHSIZE 	
**
*********************************************************************************************************************************************
** STEP 1 :   a) We recode the variables (Q0216,Q0208) from the value (-1,-2,-3) , and then multiply together to 
**                      create new variable  
**                  b) aggregate value purchase items
*********************************************************************************************************************************************

GET
  FILE='C:\IHSES_TABLES\T7\temp-HH XRations table.sav'.


COMPUTE purchaseration = Q0208 * Q0216 .
VARIABLE LABELS purchaseration 'purchase of rations items last 30 days ' .
EXECUTE .

COMPUTE Market_V = q0208 * q0206 .
VARIABLE LABELS Market_V 'Market Value for last rations (ID)' .
EXECUTE .

AGGREGATE
  /OUTFILE='C:\IHSES_TABLES\T7\agg.7-11.sav'
  /BREAK=xhhkey xgov
  /Market_V = SUM(Market_V) /q0212 = SUM(q0212) /purchaseration = SUM(purchaseration).

GET
  FILE='C:\IHSES_TABLES\T7\agg.7-11.sav'.

COMPUTE key = XHHKEY .
EXECUTE .

SORT CASES BY
  XHHKEY (A) .

SAVE OUTFILE='C:\IHSES_TABLES\T7\agg.7-11.sav'.
  
*********************************************************************************************************************************************
** STEP 2 :    Get file Household and then merg it with file agg.total value
**                  
*********************************************************************************************************************************************

GET
  FILE='C:\IHSES_TABLES\T7\temp-HH-Rations.sav'.

SORT CASES BY
  XHHKEY (A) .


MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T7\agg.7-11.sav'
 /RENAME (xgov = d0)
 /BY xhhkey
 /DROP= d0.
EXECUTE.

COMPUTE new_204A = (Q0204_A*1000) / xhhsize .
VARIABLE LABELS new_204A 'Value paid for last rations (ID/capita)' .
EXECUTE .

COMPUTE new_Market = (Market_V*1000)  / xhhsize .
VARIABLE LABELS new_Market 'Market value for last rations (ID/capita)' .
EXECUTE .

COMPUTE new_212 = (Q0212*1000) / xhhsize .
VARIABLE LABELS new_212 'Value of sold or bartered of last rations (ID/capita)' .
EXECUTE .

COMPUTE new_purchaseration = (purchaseration*1000) / xhhsize .
VARIABLE LABELS new_purchaseration 'Purchase of rations items last 30 days (ID/capita)' .
EXECUTE .

SAVE OUTFILE='C:\IHSES_TABLES\T7\temp-HH-Rations.sav' /COMPRESSED.

WEIGHT
  BY weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=new_purchaseration new_212 new_Market  new_204A  HHExpGr PCExpGr 
    DISPLAY=DEFAULT
  /TABLE HHExpGr [C] + PCExpGr  [C] BY new_purchaseration [MEAN F40 ] + new_212 [MEAN F40 ] + new_Market  [MEAN F40 ] + new_204A [MEAN F40 ] 
   /CATEGORIES VARIABLES=HHExpGr PCExpGr  ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
   TITLE= 'Table 7-11: Value paid,market value, value of sold and bartered, and value of purchased of rations items by'+
 ' expenditure groups'.

WEIGHT
  OFF.


GET
  FILE='C:\IHSES_TABLES\T7\Individuals_jobs.sav'.

SORT CASES BY
  xhhkey (A) .


MATCH FILES /FILE=*
 /TABLE='C:\IHSES_TABLES\Originals\All expenditure by subgroup.sav'
 /BY xhhkey.
EXECUTE.

WEIGHT
  BY weight .

* Custom Tables.
CTABLES
  /VLABELS VARIABLES=xhhsize PCExpGr HHExpGr DISPLAY=DEFAULT
  /TABLE PCExpGr [C] + HHExpGr [C] BY xhhsize [COUNT F40.0]
  /CATEGORIES VARIABLES=PCExpGr HHExpGr ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
   TITLE= 'Table 7-11 : Number of persons'.


WEIGHT
  OFF.

~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



