****************************************************************************************************************
**    Table 10-4:  	Household income group by head of household characteristics (% of HHs)
**    Prepared by: 	Dahlia Al Any
**    Date:		September 2007
**    Status:		Incomplete
**
**	Variables needed:
**
**		(1) Employment status (Working, Unemployed, Housekeeper, With means, Other)
**		(2) Work sector (Private, Public, Other sectors, Not economically active)
**		(3) Economic Activity (Agriculture and fishing, Mining, Manufacturing, etc.)	
**		(4) Occupation (Legislators& senior officials & managers, Professionals, etc.)
**		(5) Working Status (Employee, Employer, Own Account, Not economically active)
**		(6) Income
**
*****************************************************************************************************************
** STEP 1:  We open the file with jobs, rename the Individual ID and save it with another name 
*****************************************************************************************************************

GET FILE='C:\IHSES_TABLES\Originals\IHSES10-Jobs.sav'.
rename variable Q1200_PE = XPERS.
SORT CASES BY XHHKEY (A)  XPERS (A) .
SAVE OUTFILE='C:\IHSES_TABLES\T9\Job_10-4.sav'  /COMPRESSED.

*****************************************************************************************************************
** STEP 2:  We select the "Main Occupation", following the criteria below:
**				
**		score = sum(months worked) /12 + sum(hours_worked)/40
**		Select job with Max score
**		
*****************************************************************************************************************

IF (Q1203_01<0) Q1203_01 = 0 . 
IF (Q1203_02<0) Q1203_02 = 0 . 
IF (Q1203_03<0) Q1203_03 = 0 . 
IF (Q1203_04<0) Q1203_04 = 0 . 
IF (Q1203_05<0) Q1203_05 = 0 . 
IF (Q1203_06<0) Q1203_06 = 0 . 
IF (Q1203_07<0) Q1203_07 = 0 . 
IF (Q1203_08<0) Q1203_08 = 0 . 
IF (Q1203_09<0) Q1203_09 = 0 . 
IF (Q1203_10<0) Q1203_10 = 0 . 
IF (Q1203_11<0) Q1203_11 = 0 . 
IF (Q1203_12<0) Q1203_12 = 0 . 
IF (Q1204_01<0) Q1204_01 = 0 . 
IF (Q1204_02<0) Q1204_02 = 0 . 
IF (Q1204_03<0) Q1204_03 = 0 . 
IF (Q1204_04<0) Q1204_04 = 0 . 
IF (Q1204_05<0) Q1204_05 = 0 . 
IF (Q1204_06<0) Q1204_06 = 0 . 
IF (Q1204_07<0) Q1204_07 = 0 . 
EXECUTE .

compute sum_mths 	= sum(Q1203_01, Q1203_02, Q1203_03, Q1203_04, Q1203_05, Q1203_06, Q1203_07, Q1203_08, Q1203_09, Q1203_10, Q1203_11, Q1203_12).
formats sum_mths (F3).
compute sum_hrs 	= sum(Q1204_01, Q1204_02, Q1204_03, Q1204_04, Q1204_05, Q1204_06, Q1204_07).
formats sum_hrs (F3).
compute score 	= sum( sum_mths/12,  sum_hrs/40, (4-Q1200_SN) / 4 ) .
formats score (F2.1).

*, RV.UNIFORM(0,0.01) 

SAVE OUTFILE='C:\IHSES_TABLES\T9\Job_10-4.sav'  /COMPRESSED.
GET FILE='C:\IHSES_TABLES\T9\Job_10-4.sav'.

*************************************************************************************************************************************
***	We aggregate the number of hours for ALL possible activities of the individual:
*************************************************************************************************************************************

AGGREGATE
  /OUTFILE='C:\IHSES_TABLES\T9\temp_hrs12.sav'
  /BREAK=XHHKEY XPERS
  /sum_hrs12 = SUM(sum_hrs).

GET FILE='C:\IHSES_TABLES\T9\temp_hrs12.sav'.
SORT CASES BY   XHHKEY (A) XPERS.
SAVE OUTFILE='C:\IHSES_TABLES\T9\temp_hrs12.sav'.

GET FILE='C:\IHSES_TABLES\T9\Job_10-4.sav'.

AGGREGATE
  /OUTFILE='C:\IHSES_TABLES\T9\aggr.sav'
  /BREAK=XHHKEY XPERS
  /score = MAX(score).

GET FILE='C:\IHSES_TABLES\T9\Aggr.sav'.
SORT CASES BY   XHHKEY (A) XPERS (A) score (A) .
compute flag=1.
formats flag (N1).
SAVE OUTFILE='C:\IHSES_TABLES\T9\aggr.sav'  
/COMPRESSED.

GET FILE='C:\IHSES_TABLES\T9\Job_10-4.sav' .
SORT CASES BY   XHHKEY (A) XPERS (A) score (A) .
SAVE OUTFILE='C:\IHSES_TABLES\T9\Job_10-4.sav'  /COMPRESSED.

MATCH FILES /FILE=*
 /TABLE='C:\IHSES_TABLES\T9\aggr.sav'  /BY XHHKEY XPERS score.
EXECUTE.

** We keep only the jobs that have max score, which means flag=1

FILTER OFF.
USE ALL.
SELECT IF(flag=1).
EXECUTE .


delete variables  flag, sum_mths, sum_hrs, score.

************************************************************************************
** Now in the file Job_10-4.sav we have the MAIN job:
************************************************************************************

SAVE OUTFILE='C:\IHSES_TABLES\T9\Job_10-4.sav'  /COMPRESSED.

*****************************************************************************************************************
** STEP 3:  We open the file with individuals, and match the jobs from the new job's file and match the main
**	      occupation of each individual
*****************************************************************************************************************

GET  FILE='C:\IHSES_TABLES\Originals\IHSES02-Individuals.sav'.

SORT CASES BY   XHHKEY (A) XPERS.

MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T9\temp_hrs12.sav'
 /BY XHHKEY XPERS.
EXECUTE.

WEIGHT
  OFF.


****************************************************************************************************************
** Drop variables that we don't need and save it with another name
****************************************************************************************************************

DELETE variables Q0401_A1 Q0401_A2 Q0401_A3 Q0401_A4 Q0401_B1 Q0401_B2 Q0401_B3 Q0401_B4 Q0401_C1 Q0401_C2 Q0401_C3 Q0401_C4 Q0402
  Q0403 Q0404 Q0405 Q0406 Q0407_A Q0407_B Q0408 Q0409 Q0410L Q0410C Q0411 Q0412 Q0413 Q0414 Q0415 Q0416 Q0417 Q0418_1 Q0418_2
  Q0418_3 Q0418_4 Q0418_5 Q0418_6 Q0418_7 Q0418_8 Q0418_9 Q0501 Q0502_1 Q0502_2 Q0502_3 Q0502A_1 Q0502A_2 Q0502A_3 Q0503_A
  Q0504 Q0504A_1 Q0504A_2 Q0504A_3 Q0505_B Q0506 Q0507 Q0508_A Q0508_B Q0509 Q0510 Q0511 Q0512 Q0513 Q0514 Q0515 Q0516_1
  Q0516_2 Q0516_3 Q0516_4 Q0516_5 Q0516_6 Q0517 Q0518 Q0519 Q0520 Q0521_M Q0521_Y Q0522 Q0523 Q0524 Q0525 Q0526 Q0527 Q0528
  Q0529 Q0530 Q0531 Q0532 Q0533 Q0534 Q0601A Q0601B Q0601C Q0601D Q0601E Q0601F Q0602 Q0603_1 Q0603_2 Q0603_3 Q0603_4 Q0604_1
  Q0604_2 Q0604_3 Q0605_1 Q0605_2 Q0605_3 Q0606 .

SORT CASES BY  XHHKEY (A) XPERS (A) .


MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T9\Job_10-4.sav'
 /RENAME (XCLUSTER XGOV  XHHSIZE XSTRAT XWAVE = d0 d1 d3 d4 d5)
 /BY XHHKEY XPERS
 /DROP= d0 d1 d3 d4 d5.
EXECUTE.

FILTER OFF.
USE ALL.
SELECT IF(not missing(XCLUSTER)).
EXECUTE .


SAVE OUTFILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.

************************************************************************************
** Now in the file Individuals_jobs.sav  we have all individuals and the MAIN 
** job if there is one, if not the variables related to main job are missing
************************************************************************************

*****************************************************************************************************************
** STEP 4:  Create variable Employ_status:
**		(1) Employment status
**			1. Working	
**			2. Unemployed	
**			3. Housekeeper		
**			4. With means	
**			5. Other	
**			6. No information on jobs
*****************************************************************************************************************
** We  create auxiliary variables:
**                        Working = 1 or 0
**                        Unemployed = 1 or 0
**                        Econ_active = sum(Working, Unemployed)
**           	        NotEc_activ = ~Econ_active
**                        
*****************************************************************************************************************
**	(1)  The person is classified as "Working" if has worked during the past 7 days (Q0701) or
**	      Q1204 >0 or was in temporarily away from work due to illness or vacation 
*****************************************************************************************************************

IF ( Q0701 >0 | sum_hrs12 >0 | Q0702 = 9) Working = 1 .
EXECUTE .

**************************************************************************************************************************
**	(2)  The person is classified as "Unemployed" if 
**		a) has NOT worked during the past 7 days (Q0702), and
**	      	b) wants to work (Q0703), and
**		c) the reason for working zero hours during the past 7 days if not alternative 9, and
**		d) has searched for a job in the past (Q0705), and
**		e) is available to start working (Q0707)	
**************************************************************************************************************************

IF ( Q0701 = 0 & ( sum_hrs12 = 0 | missing(sum_hrs12) ) &  Q0703 = 1 & Q0702 ~= 9 & Q0705 ~= 4 & Q0707 = 1) Unemployed = 1 .
EXECUTE .

COMPUTE Econ_active = SUM(Unemployed ,Working) . 
VARIABLE LABEL   Econ_active 'Unemployed+Working'.
EXECUTE .

RECODE
  Econ_active  (SYSMIS=0)  .
EXECUTE .

IF (Econ_active = 0) NotEc_activ= 1 .
IF (Econ_active = 1) NotEc_activ= 0 .
VARIABLE LABEL   NotEc_activ 'Not economic activity'.
EXECUTE .

*****************************************************************************************************************
**	(3)  The person is classified as "Houskeeper" if is housekeeper in Q0702 and if the reason in 
**	      Q0704 is not that has other source of income or that cannot find a job.
*****************************************************************************************************************

IF (Q0701 = 0 & ( sum_hrs12 = 0 | missing(sum_hrs12) ) & ( Q0703 <> 1 or missing(Q0703) )  & Q0702 = 7  &  Q0704  =  4 ) Housekeeper  = 1 .
EXECUTE .

*****************************************************************************************************************
**	(4)  The person is classified as "With means" if Q0702 between codes 5-6 or 8, and Reason 
**	      in Q0704 = 10.
*****************************************************************************************************************

IF (Q0701 = 0 & ( sum_hrs12 = 0 | missing(sum_hrs12) ) &  ( Q0702 = 5 | Q0702 = 6 | Q0702 = 8)  & Q0704 = 10 & NotEc_activ = 1) Withmeans = 1 .
EXECUTE .

*****************************************************************************************************************

IF (Working=1) 				Employ_status=1.
IF (Unemployed=1) 			Employ_status=2.
IF (Housekeeper=1) 			Employ_status=3.
IF (Withmeans=1) 			Employ_status=4.
IF (missing(Employ_status)) 	Employ_status=5.

VARIABLE LABEL Employ_status  'Employment status'.
VALUE LABELS Employ_status  1'Working' 2 'Unemployed' 3'Housekeeper' 4'Withmeans' 5' Other' .
EXECUTE .

FREQUENCIES   VARIABLES=Employ_status   /ORDER=  ANALYSIS .

*****************************************************************************************************************
**  +++++  Which individuals should we keep in the file? Only those aged 6 years and more? ++++++++
**  FILTER OFF.
**  USE ALL.
**  SELECT IF(Q0103>=15).
**  EXECUTE .
** 
**  FREQUENCIES   VARIABLES=Employ_status   /ORDER=  ANALYSIS .
*****************************************************************************************************************

*****************************************************************************************************************
** STEP 5:  Create variable Sector:
**		(2) Work sector
**			1. Private	
**			2. Public	
**			3. Govermental
**			4. Other sectors	
**			5. Not economically active	
**			
*****************************************************************************************************************

IF (Q1202A =1) 				Sector  = Q1303.
IF (Q1202B1=1|Q1202B2=1) 	Sector  =           3.
IF MISSING(Sector)                       Sector  =         11.
IF (NotEc_activ = 1) 			Sector  =         12.
IF (Unemployed=1) 			Sector  =         13.
VARIABLE LABELS Sector  'Work sector' .

RECODE
  Sector   (3=1)  (2=2)  (1=3) (4 thru 10=4)  (11=5) (12=6) (13=7) .
VALUE LABELS Sector  1'Private' 2'public' 3'Govermental' 4'other sectors' 5'Unknown' 6'Not economically active' 7'Unemployed' .

SAVE OUTFILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.

FREQUENCIES   VARIABLES=Sector   /ORDER=  ANALYSIS .

*****************************************************************************************************************
** STEP 6:  Create variable Occupation:
**			1. Legislators& senior officials & managers	
**			2. Professionals	
**			3. Technicians & associate professionals	
**			4. Clerks	
**			5. Services and sales workers	
**			6. skilled agriculture & fishery workers	
**			7. Craft & related trade workers	
**			8. Plant& machine operators& assembl.	
**			9. Elementary occupations	
**			10. Other occupations	
**			11. Not economically active	
*****************************************************************************************************************

COMPUTE Occupation  = TRUNC(Q1201/1000) .

**if some cases equal 0 add them to to Elementary Occupation
**if some cases are missing add to unknown

IF (Occupation  = 0) Occupa_gr= 9  .                 
IF (Occupation  > 0) Occupa_gr= Occupation  .
IF MISSING(Occupation) Occupa_gr= 10.
IF (NotEc_activ  =1) Occupa_gr= 11 .
IF (Unemployed=1)  Occupa_gr = 12 .

VARIABLE LABELS Occupation  'Occupation' .
VARIABLE LABELS Occupa_gr  'Occupation group' .
EXECUTE .


VALUE LABELS Occupa_gr 
  0 'Other Occupations'
  1'Lagislatores and senior officials & mangers'
  2 'Professionals'
  3'Technicians & associate profess'
  4'Clerks'
  5'Services and sales workers'
  6'Skilled agriculture & fishery workers'
  7'Craft & related trade workers'
  8'Plant machine operatores & assemblers'
  9'Elementary Occupation'
 10'Unknown'
11'Not Economically active'
12'Unemplyed'.
EXECUTE . 

FREQUENCIES   VARIABLES=Occupa_gr  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.

*****************************************************************************************************************
** STEP 7:  Create variable Econ. activity:
**			1  'Agriculture & Hunting' 
 **			2  'Fishing'
 **			3  'Mining' 
 **			4  'Manufacturing industry' 
 **			5  'Electricity, gas ,water'
 **			6  'Building and construction' 
 **			7  'Wholesale & Retail Trade, repair of motor vehicles '
**			 8  'Trade,Resturant &Hotels'
**			 9  'Transportation &Communications'
**			 10'Finance  intermediation'
**			 11'Real estate , renting and business activities'
**			 12'Public administration and defence ; compulsory'
**			 13'Education'
**			 14'Health and Social Work'
**			 15'Other community , social and personal services activities '
**			 16'Housing services'
**			 17'Extra-territorial Organizations and bodies'
**			 18' Not Economically active'
**			 19'Unemplyed' .
*****************************************************************************************************************

GET
  FILE='C:\IHSES_TABLES\Originals\IHSES11-Self-employment activities.sav'.

STRING 	 Act_cod (A1).
COMPUTE Act_cod = q1205cod .
EXECUTE .

SORT CASES BY XHHKEY (A) Act_cod (A) .

SAVE OUTFILE='C:\IHSES_TABLES\T9\Self-employment activities_code.sav'.

GET FILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.

STRING      Act_cod (A1).
COMPUTE Act_cod = Q1202E .
EXECUTE .

SORT CASES BY XHHKEY (A) Act_cod (A) .

MATCH FILES /FILE=*
 /TABLE='C:\IHSES_TABLES\T9\Self-employment activities_code.sav'
 /RENAME (XCLUSTER XGOV  XHHSIZE XSTRAT XWAVE = d0 d1 d3 d4 d5)
 /BY XHHKEY Act_cod 
 /DROP= d0 d1 d3 d4 d5.
EXECUTE.

SAVE OUTFILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.

IF (MISSING(Q1302) | MISSING(q1205act)) Per_Activ = SUM(Q1302,q1205act) .
VARIABLE LABELS Per_Activ 'Persons Activity' .
EXECUTE .

COMPUTE Activity_gr = TRUNC(Per_Activ/10) .

VARIABLE LABELS Activity_gr 'Main Economic Activity' .
EXECUTE .

IF  ((Activity_gr=01|Activity_gr=02|Activity_gr=05) | Q1202B1=1)	Activity_gr=1.
IF  (Activity_gr >= 10 & Activity_gr <= 14) 			Activity_gr=3.
IF  (Activity_gr >= 15 & Activity_gr <= 37) 			Activity_gr=4.
IF  (Activity_gr = 40 | Activity_gr = 41) 				Activity_gr=5.
IF  (Activity_gr = 45)   							Activity_gr =6.
IF  (Activity_gr >= 50 & Activity_gr <= 52) 			Activity_gr=7.
IF  (Activity_gr = 55) 							Activity_gr=8.
IF  (Activity_gr >= 60 & Activity_gr <= 64) 			Activity_gr=9.
IF  (Activity_gr >= 65 & Activity_gr <= 67)|(Activity_gr >= 70 & Activity_gr <= 74)			Activity_gr=10.
IF  (Activity_gr =75) 							Activity_gr =12.
IF  (Activity_gr =80) 							Activity_gr =13.
IF  (Activity_gr =85) 							Activity_gr =14.
IF  ((Activity_gr >= 90 & Activity_gr <= 93)| (Activity_gr >= 95 & Activity_gr <= 97)|(Activity_gr =99))			Activity_gr=15.
IF  MISSING(Activity_gr)                                                       Activity_gr= 18.
IF (NotEc_activ >0) 							Activity_gr =19.
IF (Unemployed=1) 							Activity_gr =20 .

VALUE LABELS Activity_gr 
 1  'Agriculture & Hunting' 
 3  'Mining' 
 4  'Manufacturing industry' 
 5  'Electricity, gas ,water'
 6  'Building and construction' 
 7  'Wholesale & Retail Trade, repair of motor vehicles '
 8  'Trade,Resturant &Hotels'
 9  'Transportation &Communications'
 10' Finance  intermediation &Real estate,renting and business activities'
 12'Public administration and defence compulsory'
 13'Education'
 14'Health and Social Work'
 15'Other community social'
 18'Unknown'
 19' Not Economically active'
 20'Unemplyed' .
EXECUTE .

FREQUENCIES   VARIABLES=Activity_gr  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.

*****************************************************************************************************************
** STEP 8:  Create variable Work status:  Work_status
**			1. Employee	
**			2. Employer	
**			3. Own Account	
**			4. Not economically active	
*****************************************************************************************************************
**	We need to create two variables to be able to determine whether the person is 
**	employer or not.  The criteria is:
**
**	If (a) the household in agriculture or (b) the enterprise pays wages to employees, 
**	that means is employer
**
**	(1) Employer in Self-employment/enterprise, Ind_employer_in_self
**			if line 1431 or 1432 are > 0 	==> EMPLOYER
**	(2) Employer in Self-employment/enterprise, Ind_employer_in_agric
**			if Q1407H  > 0 or  Q1414_14 > 0 or Q1416CC > 0 or Q1417A > 0
**								==> EMPLOYER	
*****************************************************************************************************************

**	(1) Employer in Self-employment/enterprise, Ind_employer_in_self

GET FILE='c:\IHSES_TABLES\Originals\IHSES11-Self-employment activities.sav'.

COMPUTE Ind_employer_in_self = 0 .
IF (SUM(Q1431,Q1432) > 0) Ind_employer_in_self = 1 .
EXECUTE .
value lables Ind_employer_in_self  0 'No' 1 'Yes'.
SORT CASES BY XHHKEY (A) q1205cod (A) .
SAVE OUTFILE='C:\IHSES_TABLES\T9\temp_self_emplyer.sav'
 /COMPRESSED.

**	(2) Employer in agriculture, Ind_employer_in_agric

GET FILE='c:\IHSES_TABLES\Originals\IHSES06-Crop production.sav'.

AGGREGATE
  /OUTFILE='C:\IHSES_TABLES\T9\agr_crop_wage.sav'
  /BREAK=XHHKEY
  /Q1407H = SUM(Q1407H).

GET FILE='C:\IHSES_TABLES\T9\agr_crop_wage.sav'.
SORT CASES BY XHHKEY (A) .

SAVE OUTFILE='C:\IHSES_TABLES\T9\agr_crop_wage.sav'
 /COMPRESSED.

GET FILE='c:\IHSES_TABLES\Originals\IHSES01-Household.sav'.
SORT CASES BY XHHKEY (A) .

MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T9\agr_crop_wage.sav'
 /BY XHHKEY.
EXECUTE.

SAVE OUTFILE='C:\IHSES_TABLES\T9\temp_HH_employer.sav'
  /DROP=XCLUSTER XHHSIZE Q0002 Q0003 Q0007 Q0008 Q0012 Q0014 Q0017 Q0018 Q0029 Q0032 Q0034 Q0035D Q0035M Q0035Y Q0036D Q0036M
  Q0036Y Q0037D Q0037M Q0037Y Q0038D Q0038M Q0038Y Q0039D Q0039M Q0039Y Q0040 QTUSE1 QLANG1 Q0201 Q0202 Q0203_A Q0203_B
  Q0203_C Q0204_A Q0204_B Q0204_C Q0204_D Q0301 Q0302 Q0303 Q0304 Q0305 Q0306 Q0307 Q0308A Q0308B Q0309_01 Q0310_01 Q0309_02
  Q0310_02 Q0309_03 Q0310_03 Q0309_04 Q0310_04 Q0309_05 Q0310_05 Q0309_06 Q0310_06 Q0309_07 Q0310_07 Q0309_08 Q0310_08
  Q0309_09 Q0310_09 Q0309_10 Q0310_10 Q0309_11 Q0310_11 Q0311A Q0311B Q0311C Q0312 Q0313 Q0314 Q0315 Q0316 Q0317 Q0318A Q0318B
  Q0318C Q0318D Q0319 Q0320 Q0321 Q0322 Q0323_1 Q0323_2 Q0323_3 Q0324_1 Q0325_1 Q0324_2 Q0325_2 Q0324_3 Q0325_3 Q0326_11
  Q0326_12 Q0326_13 Q0326_14 Q0326_15 Q0326_16 Q0326_21 Q0326_22 Q0326_23 Q0326_24 Q0326_25 Q0326_26 Q0326_31 Q0326_32
  Q0326_33 Q0326_34 Q0326_35 Q0326_36 Q0326_41 Q0326_42 Q0326_43 Q0326_44 Q0326_45 Q0326_46 Q0327 Q0328 Q0329 Q0330 Q0331_01
  Q0331_02 Q0331_03 Q0331_04 Q0331_05 Q0331_06 Q0331_07 Q0331_08 Q0331_09 Q0331_10 Q0331_11 Q0331_12 Q0331_13 Q0332 Q0334
  Q0335_01 Q0335_02 Q0335_03 Q0335_04 Q0335_05 Q0335_06 Q0335_07
  Q0335_08 Q0335_09 Q0335_10 Q0335_11 Q0335_12 Q0335_13 Q0335_14 Q0335_15 Q0335_16 Q0336_1 Q0336_2 Q0336_3 Q0336_4 Q0336_5 
  Q0339_01 Q0339_02 Q0339_03 Q0339_04 Q0339_05 Q0339_06 Q0339_07 Q1401 Q1402 Q1403_1 Q1403_2 Q1403_3 Q1403_4 Q1404
  Q1409 Q1410_01 Q1410_02 Q1410_03 Q1410_04 Q1410_05 Q1410_06 Q1410_07 Q1410_08 Q1411 Q1412 Q1413 Q1413A Q1414_01 Q1414_02
  Q1414_03 Q1414_04 Q1414_05 Q1414_06 Q1414_07 Q1414_08 Q1414_09 Q1414_10 Q1414_11 Q1414_12 Q1414_13 Q1414_15 Q1414_16
  Q1414_17 Q1414_18 Q1414_19 Q1414_20 Q1414_21 Q1414_22 Q1414_23 Q1414_24 Q1414_25 Q1415 Q1416A Q1416AA Q1416B Q1416BB Q1416C
  Q1417B Q1417C Q1417_A Q1417_B Q1417_C Q1417_D Q1602_01 Q1602_02 Q1602_03 Q1602_04 Q1602_05 Q1602_06 Q1602_07 Q1602_08
  Q1602_09 Q1602_10 Q1602_11 Q1602_12 Q1602_13 Q1602_14 Q1602_15 Q1602_16 Q1602_17 Q1602_18 Q1602_19 Q1602_20 Q1602_21
  Q1602_22 Q1602_23 Q1602_24 Q1602_25 Q1602_26 Q1602_27 Q1602_28 Q1602_29 Q1602_30 Q1602_31 Q1602_32 Q1602_33 Q1602_34
  Q1602_35 Q1602_36 Q1701 Q1702_1 Q1702_2 Q1702_3 Q1703_1 Q1703_2 Q1703_3 Q1704 Q1705_1 Q1705_2 Q1705_3 Q1801_01 Q1801_02
  Q1801_03 Q1801_04 Q1801_05 Q1801_06 Q1801_07 Q1801_08 Q1801_09 Q1801_10 Q1801_11 Q1802_01 Q1802_02 Q1802_03 Q1802_04
  Q1802_05 Q1802_06 Q1802_07 Q1802_08 Q1802_09 Q1802_10 Q1802_11 Q1802_12 Q1802_13 Q1802_14 Q1802_15 Q1802_16 Q1802_17
  Q1802_18 Q1802_19 Q1802_20 Q1802_21 Q1802_22 Q1802_23 Q1802_24 weight /COMPRESSED.

GET FILE='C:\IHSES_TABLES\T9\temp_HH_employer.sav'.

COMPUTE Ind_employer_in_agric = 0 .
IF (SUM(Q1414_14,Q1416CC,Q1417A,Q1407H) > 0) Ind_employer_in_agric= 1 .
EXECUTE .

value lables Ind_employer_in_agric
0 'No'
1 'Yes'.
EXECUTE .

SAVE OUTFILE='C:\IHSES_TABLES\T9\temp_HH_employer.sav'.
 

** We add both indicators into the file with individuals and their main job:  Individuals_jobs.sav

GET FILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.
SORT CASES BY XHHKEY (A) .

MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T9\temp_HH_employer.sav'
 /RENAME (Q1407H Q1414_14 Q1416CC Q1417A XGOV XSTRAT XWAVE = d0 d1 d2 d3 d4 d6 d7)
 /BY XHHKEY
 /DROP= d0 d1 d2 d3 d4 d6 d7.
EXECUTE.

SAVE OUTFILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.

GET FILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.
SORT CASES BY XHHKEY (A) q1205cod (A) .


*?????

MATCH FILES /FILE=*
 /TABLE='C:\IHSES_TABLES\T9\temp_self_emplyer.sav'
 /RENAME (q1205act q1206_m1 q1206_m2 q1206_m3 q1206_m4 q1206_m5 q1418 q1419 q1420 q1421 q1422 q1423 q1424 q1425 q1426 q1427
  q1428 q1429 q1430 q1431 q1432 q1433 q1434 q1436 q1437 q1438 q1439 q1440 q1441 q1443 q1444a q1444b q1444c q1444d q1444e
  q1444f q1444g q1444h q1444i q1445 q1446 q1447 q1448 q1449 q1450 q1451 q1452 xcluster xgov xhhsize xstrat xwave = d0 d1
  d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 d32 d33 d34
  d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 d51 d52)
 /BY xhhkey q1205cod
 /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31
  d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 d51 d52.
EXECUTE.

*???????


SAVE OUTFILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.


** We create now the variable Work_status:
**			1. Employee	
**			2. Employer	
**			3. Own Account	
**			4. Not economically active	
**			5. Unemployment	

IF (Q1202A =1) 									Work_status=1. 
IF (Q1202B1 =1) or  (Q1202B2 =1)					Work_status=3.
IF (Ind_employer_in_agric=1) or  (Ind_employer_in_self=1)	Work_status=2.
IF MISSING(Work_status) 							Work_status=4. 
IF (NotEc_activ=1) 								Work_status=5. 
IF (Unemployed=1) 								Work_status=6. 

var lab Work_Status "Work status".
value lab Work_Status
1 Employee	
2 Employer	
3 'Own Account'
4  'Unknown'
5  'Not economically active'	
6  'Unemployment'.
execute.

FREQUENCIES   VARIABLES=Work_Status  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.


**Selecting just head of the household

FILTER OFF.
USE ALL.
SELECT IF(XPERS = 1).
EXECUTE .

formats XHHKEY (F9).

SAVE OUTFILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.

GET
  FILE='C:\IHSES_TABLES\T9\Household & Income.sav'.

SORT CASES BY
  XHHKEY (A) .

************Now using the variables 
**Employ-status
**sector
**Activity _gr
**Occupation_gr
**work status
****************************************

GET
  FILE='C:\IHSES_TABLES\T9\Individuals_jobs.sav'.

SORT CASES BY
  XHHKEY (A) .


MATCH FILES /FILE=*
 /FILE='C:\IHSES_TABLES\T9\Household & Income.sav'
 /RENAME ( weight xcluster xgov  xhhsize xstrat xwave =  d42
  d43 d44  d46 d47 d48)
 /BY xhhkey
 /DROP=  d42 d43 d44 d46 d47 d48.
EXECUTE.

************************************************************************************************************************
*** if occupation is  Lagislatores and senior officials & mangers and income under 500000 ID
*** the code moved to unknown
************************************************************************************************************************

IF Occupa_gr =1 & (HHincmGRP=1  | HHincmGRP=2 )      Occupa_gr =10.
    

WEIGHT
  BY weight .


* Custom Tables.
CTABLES
  /VLABELS VARIABLES=HHincmGRP Employ_status Sector Occupa_gr Activity_gr Work_status DISPLAY=DEFAULT
  /TABLE Employ_status [C] + Sector [C] + Occupa_gr [C] + Activity_gr [C] + Work_status [C] BY HHincmGRP [C][ROWPCT.COUNT
  PCT40.1]
  /CATEGORIES VARIABLES=HHincmGRP Employ_status Sector Occupa_gr Activity_gr Work_status ORDER=A KEY=VALUE EMPTY=INCLUDE
  TOTAL=YES POSITION=AFTER.

